# -*- coding: utf-8 -*-
###############################################################################
# Copyright (c), Forschungszentrum Jülich GmbH, IAS-9, Germany.               #
#                All rights reserved.                                         #
# This file is part of the survey_dashboard package.                          #
#                                                                             #
# The code is hosted on GitHub at                                             #
# https://github.com/Materials-Data-Science-and-Informatics/survey_dashboard  #
# For further information on the license, see the LICENSE file                #
###############################################################################
"""
This is the central place for all text from the dashboard which needs to be translated
"""


# Description
md_text_description = {'EN': ("Explorer interactively the HMC 2021 Survey results. "
    "The overview sections displays some main results, while you can apply some global filters to these. " 
    "Find out what methods, tools, software and standards are applied by others in your research area. "
    "The question explorer allows for in detail analysis of a specific question and simple correlations of two questions. "
    "Interact with the visualizations and widgets on the left to explorer the data.\n"
    "The corresponding Data publication of the survey is available [here](https://doi.org/10.7802/2433).\n"
    "\n "
    "DISCLAIMER: Be careful in drawing any conclusions, especially on filtered results! "
    "The usable sample size of the survey 2021 was 2.3% of all Helmholtz employees at the time, of "# <3
    "which only the onces are published and displayed who provided consent. "
    "Therefore, the sample is often to small to be an accurate representation of the whole HGF "
    "and or to unbiased accurately sample the underlying true distributions!\n"
    "\n"
    "Any Feedback is welcome and can be given [here](https://github.com/Materials-Data-Science-and-Informatics/survey_dashboard)"),
    'DE':('Exploriere interakiv die Resultate der HMC 2021 Umfrage.')}



## Global data filters\n 
md_text_global_filter = {'EN': ("Apply filters to displayed data according to research areas and data generation method"),
                         'DE': ("Wende Filter auf die Resultate an um nur Daten bestimmter "
                         "Forschungsfelder und Erzeugungsmethode dazustellen.")}

md_text_global_filters_widgets = [{'EN': "Research area", 'DE': "Forschungsfeld"}, {'EN': "Data generation method", 'DE': "Datenerzeugungs Methode"}]

# Overview\n
md_text_overview = {'EN': "Birds eye view of survey results related to research data management.",
                    'DE': "Übersicht mit hervorgehobene Fragen zum Forschungsdatenmanagement"}




# Tools and Methods\n 
md_text_tools_used = {'EN': ("Discover the scientific methods, used software and repositories of our communities."),
                    'DE': ("Entdecke die wissenschaftliche Methoden, Werkzeuge, Software und Repositorien welche in unseren Forschungsgemeinschaft "
                    "genutzt werden.")}

# Question explorer

md_text_barchart = {'EN': ("Select two questions to explore answers and see how they correspond to one another."),
                    'DE': ("Wähle zwei Fragen aus um deren Anworten zu sehen und wie diese übereinstimmen.")}

md_text_select_widgets = [{'EN': "Question 1", 'DE': "Frage 1"}, {'EN': "Question 2", 'DE': "Frage 2"}]
# Basic Correlations\n
md_text_corrchart = {'EN': "Correspondence of selected questions",
                    'DE': "Korrespondenz der ausgewählten Fragen"}

md_text_button = {'EN': ("# Further charts\n")}

accordion_titles = {
    'EN': ['Global Data Filters', 'Overview', 'Methods, Tools and Software', 'Survey Data Explorer'],
    'DE': ['Globale Datenfilter', 'Überblick', 'Methoden, Werkzeuge und Software', 'Umfrage-explorer']
}


# -*- coding: utf-8 -*-
###############################################################################
# Copyright (c), Forschungszentrum Jülich GmbH, IAS-9, Germany.               #
#                All rights reserved.                                         #
# This file is part of the survey_dashboard package.                          #
#                                                                             #
# The code is hosted on GitHub at                                             #
# https://github.com/Materials-Data-Science-and-Informatics/survey_dashboard  #
# For further information on the license, see the LICENSE file                #
###############################################################################
"""
A collection of dictionaries/maps to influence the display of certain categorical data
"""

##########################################
############### DICTIONARY ###############
########## RENAME COLUMN NAMES ###########
########################################## 

# Dictionary to rename columns in df for better readability 

HCS_colnamesDict = {
        "PERBG1/_":"centerAffiliation",
        "PERBG1/other":"centerAffiliation_other",
        "PERBG2/_":"researchFieldHGF",
        "PERBG3/_": "researchArea",
        "PERBG3/other":"researchArea_other",
        "PERBG3ING/_":"researchAreaING",
        "PERBG3ING/other":"researchAreaING_other",
        "PERBG3GEO/_":"researchAreaGEO",
        "PERBG3GEO/other":"researchAreaGEO_other",
        "PERBG3MATH/_":"researchAreaMATH",
        "PERBG3MATH/other":"researchAreaMATH_other",
        "PERBG3PHYS/_":"researchAreaPHYS",
        "PERBG3PHYS/other":"researchAreaPHYS_other",
        "PERBG3LIFE/_":"researchAreaLIFE",
        "PERBG3LIFE/other":"researchAreaLIFE_other",
        "PERBG3BIO/_":"researchAreaBIO",
        "PERBG3BIO/other":"researchAreaBIO_other",
        "PERBG3MED/_":"researchAreaMED",
        "PERBG3MED/other":"researchAreaMED_other",
        "PERBG3AGRI/_":"researchAreaAGRI",
        "PERBG3AGRI/other":"researchAreaAGRI_other",
        "PERBG3PSYCH/_":"researchAreaPSYCH",
        "PERBG3PSYCH/other":"researchAreaPSYCH_other",
        "PERBG3CHEM/_":"researchAreaCHEM",
        "PERBG3CHEM/other":"researchAreaCHEM_other",
        "PERBG4/_":"yearsInResearch",
        "PERBG6/_":"careerLevel",
        "PERBG6/other":"careerLevel_other",
        "PERBG7/_":"orcid",
        "PERBG8/_":"fairFamiliarity",
        "RSDP1/1A2":"dataOrigin_MeasVsSim",
        "RSDP1/3A4":"dataOrigin_SelvVsReuse",
        "RSDP1b/1":"dataAmount_lsf",
        "RSDP1c/1":"lsfIdent_1",
        "RSDP1c/2":"lsfIdent_2",
        "RSDP1c/3":"lsfIdent_3",
        "RSDP1c/4":"lsfIdent_4",
        "RSDP1c/5":"lsfIdent_5",
        "RSDP1c/6":"lsfIdent_6",
        "RSDP1c/7":"lsfIdent_7",
        "RSDP1c/8":"lsfIdent_8",
        "RSDP1c/9":"lsfIdent_9",
        "RSDP1c/10":"lsfIdent_10",
        "RSDP1c/11":"lsfIdent_11",
        "RSDP1c/other":"lsfIdent_other",
        "RSDP2/1":"dataGenMethod_1",
        "RSDP2/2":"dataGenMethod_2",
        "RSDP2/3":"dataGenMethod_3",
        "RSDP2/4":"dataGenMethod_4",
        "RSDP2/5":"dataGenMethod_5",
        "RSDP2/6":"dataGenMethod_6",
        "RSDP2/other":"dataGenMethod_other",
        "RSDP2b/1-1":"dataGenMethodSpec_1_1",
        "RSDP2b/1-2":"dataGenMethodSpec_1_2",
        "RSDP2b/1-3":"dataGenMethodSpec_1_3",
        "RSDP2b/2-1":"dataGenMethodSpec_2_1",
        "RSDP2b/2-2":"dataGenMethodSpec_2_2",
        "RSDP2b/2-3":"dataGenMethodSpec_2_3",
        "RSDP2b/3-1":"dataGenMethodSpec_3_1",
        "RSDP2b/3-2":"dataGenMethodSpec_3_2",
        "RSDP2b/3-3":"dataGenMethodSpec_3_3",
        "RSDP2b/4-1":"dataGenMethodSpec_4_1",
        "RSDP2b/4-2":"dataGenMethodSpec_4_2",
        "RSDP2b/4-3":"dataGenMethodSpec_4_3",
        "RSDP2b/5-1":"dataGenMethodSpec_5_1",
        "RSDP2b/5-2":"dataGenMethodSpec_5_2",
        "RSDP2b/5-3":"dataGenMethodSpec_5_3",
        "RSDP2b/6-1":"dataGenMethodSpec_6_1",
        "RSDP2b/6-2":"dataGenMethodSpec_6_2",
        "RSDP2b/6-3":"dataGenMethodSpec_6_3",
        "RSDP2b/7-1":"dataGenMethodSpec_7_1",
        "RSDP2b/7-2":"dataGenMethodSpec_7_2",
        "RSDP2b/7-3":"dataGenMethodSpec_7_3",
        "RSDP3/1":"dataFormats_1",
        "RSDP3/2":"dataFormats_2",
        "RSDP3/3":"dataFormats_3",
        "RSDP3/4":"dataFormats_4",
        "RSDP3/5":"dataFormats_5",
        "RSDP3/6":"dataFormats_6",
        "RSDP3/7":"dataFormats_7",
        "RSDP3/8":"dataFormats_8",
        "RSDP3/9":"dataFormats_9",
        "RSDP3/10":"dataFormats_10",
        "RSDP3/11":"dataFormats_11",
        "RSDP3/12":"dataFormats_12",
        "RSDP3/13":"dataFormats_13",
        "RSDP3/14":"dataFormats_14",
        "RSDP3/15":"dataFormats_15",
        "RSDP3/other":"dataFormats_other",
        "RSDP7/_":"dataInPublication",
        "RSDP4/_":"dataGatherTime",
        "RSDP8/_":"experimentDuration_sub",
        "RSDP11/_":"dataAnalDuration_sub",
        "RSDP10/_":"longtermStorage",
        "DTPUB6/1":"pubAmount",
        "DTPUB1b/1":"pubMethod_1",
        "DTPUB1b/2":"pubMethod_2",
        "DTPUB1b/3":"pubMethod_3",
        "DTPUB1b/other":"pubMethod_other",
        "DTPUB5/1":"pubRepo_1",
        "DTPUB5/2":"pubRepo_2",
        "DTPUB5/3":"pubRepo_3",
        "DTPUB5/4":"pubRepo_4",
        "DTPUB5/5":"pubRepo_5",
        "DTPUB3/1":"pubMotivation_1",
        "DTPUB3/2":"pubMotivation_2",
        "DTPUB3/3":"pubMotivation_3",
        "DTPUB3/4":"pubMotivation_4",
        "DTPUB3/5":"pubMotivation_5",
        "DTPUB3/6":"pubMotivation_6",
        "DTPUB3/7":"pubMotivation_7",
        "DTPUB3/other":"pubMotivation_other",
        "DTPUB4a/0":"pubObstaclesA_0",
        "DTPUB4a/1":"pubObstaclesA_1",
        "DTPUB4a/2":"pubObstaclesA_2",
        "DTPUB4a/3":"pubObstaclesA_3",
        "DTPUB4a/4":"pubObstaclesA_4",
        "DTPUB4a/5":"pubObstaclesA_5",
        "DTPUB4a/6":"pubObstaclesA_6",
        "DTPUB4a/7":"pubObstaclesA_7",
        "DTPUB4a/other":"pubObstaclesA_other",
        "DTPUB4b/0":"pubObstaclesB_0",
        "DTPUB4b/1":"pubObstaclesB_1",
        "DTPUB4b/2":"pubObstaclesB_2",
        "DTPUB4b/3":"pubObstaclesB_3",
        "DTPUB4b/4":"pubObstaclesB_4",
        "DTPUB4b/5":"pubObstaclesB_5",
        "DTPUB4b/6":"pubObstaclesB_6",
        "DTPUB4b/7":"pubObstaclesB_7",
        "DTPUB4b/other":"pubObstaclesB_other",
        "RDMPR1/0":"dataStorage_0",
        "RDMPR1/1":"dataStorage_1",
        "RDMPR1/2":"dataStorage_2",
        "RDMPR1/3":"dataStorage_3",
        "RDMPR1/other":"dataStorage_other",
        "RDMPR3/0":"docMethod_0",
        "RDMPR3/1":"docMethod_1",
        "RDMPR3/2":"docMethod_2",
        "RDMPR3/3":"docMethod_3",
        "RDMPR3/other":"docMethod_other",
        "RDMPR7/2":"docMetadata_2",
        "RDMPR7/3":"docMetadata_3",
        "RDMPR7/4":"docMetadata_4",
        "RDMPR7/5":"docMetadata_5",
        "RDMPR7/6":"docMetadata_6",
        "RDMPR7/7":"docMetadata_7",
        "RDMPR7/8":"docMetadata_8",
        "RDMPR7/9":"docMetadata_9",
        "RDMPR7/other":"docMetadata_other",
        "RDMPR8/2":"docDigital_2",
        "RDMPR8/3":"docDigital_3",
        "RDMPR8/4":"docDigital_4",
        "RDMPR8/5":"docDigital_5",
        "RDMPR8/6":"docDigital_6",
        "RDMPR8/7":"docDigital_7",
        "RDMPR8/8":"docDigital_8",
        "RDMPR8/9":"docDigital_9",
        "RDMPR8/10":"docDigital_other",
        "RDMPR9/2":"docAuto_2",
        "RDMPR9/3":"docAuto_3",
        "RDMPR9/4":"docAuto_4",
        "RDMPR9/5":"docAuto_5",
        "RDMPR9/6":"docAuto_6",
        "RDMPR9/7":"docAuto_7",
        "RDMPR9/8":"docAuto_8",
        "RDMPR9/9":"docAuto_9",
        "RDMPR9/10":"docAuto_other",
        "RDMPR4/_":"docStructured",
        "RDMPR5/_":"docDefSchema",
        "DTPUB7/0":"pubMetadata_0",
        "DTPUB7/1":"pubMetadata_1",
        "DTPUB7/21":"pubMetadata_21",
        "DTPUB7/22":"pubMetadata_22",
        "DTPUB7/23":"pubMetadata_23",
        "DTPUB7/24":"pubMetadata_24",
        "DTPUB7/31":"pubMetadata_31",
        "DTPUB7/32":"pubMetadata_32",
        "DTPUB7/33":"pubMetadata_33",
        "DTPUB7/41":"pubMetadata_41",
        "DTPUB7/42":"pubMetadata_42",
        "DTPUB7/43":"pubMetadata_43",
        "DTPUB7/44":"pubMetadata_44",
        "DTPUB7/51":"pubMetadata_51",
        "DTPUB7/52":"pubMetadata_52",
        "DTPUB7/61":"pubMetadata_61",
        "DTPUB7/62":"pubMetadata_62",
        "DTPUB7/71":"pubMetadata_71",
        "DTPUB7/72":"pubMetadata_72",
        "DTPUB7/81":"pubMetadata_81",
        "DTPUB7/82":"pubMetadata_82",
        "DTPUB7/83":"pubMetadata_83",
        "DTPUB7/91":"pubMetadata_91",
        "DTPUB7/92":"pubMetadata_92",
        "DTPUB7/93":"pubMetadata_93",
        "DTPUB7/other":"pubMetadata_other",
        "RDMPR6/1":"docStandards_1",
        "RDMPR6/2":"docStandards_2",
        "RDMPR6/3":"docStandards_3",
        "RDMPR6/4":"docStandards_4",
        "RDMPR6/5":"docStandards_5",
        "RDMPR6/6":"docStandards_6",
        "RDMPR6/7":"docStandards_7",
        "RDMPR6/8":"docStandards_8",
        "RDMPR6/9":"docStandards_9",
        "RDMPR6/10":"docStandards_10",
        "RDMPR6/11":"docStandards_11",
        "RDMPR6/12":"docStandards_12",
        "RDMPR6/13":"docStandards_13",
        "RDMPR6/14":"docStandards_14",
        "RDMPR6/15":"docStandards_15",
        "RDMPR6/16":"docStandards_16",
        "RDMPR6/17":"docStandards_17",
        "RDMPR6/18":"docStandards_18",
        "RDMPR6/19":"docStandards_19",
        "RDMPR6/20":"docStandards_20",
        "RDMPR6/21":"docStandards_21",
        "RDMPR6/22":"docStandards_22",
        "RDMPR6/23":"docStandards_23",
        "RDMPR6/24":"docStandards_24",
        "RDMPR6/25":"docStandards_25",
        "RDMPR6/26":"docStandards_26",
        "RDMPR6/other":"docStandards_other",
        "RDMPR10/1":"software_1",
        "RDMPR10/2":"software_2",
        "RDMPR10/3":"software_3",
        "RDMPR12/0":"docMotivation_0",
        "RDMPR12/1":"docMotivation_1",
        "RDMPR12/2":"docMotivation_2",
        "RDMPR12/3":"docMotivation_3",
        "RDMPR12/4":"docMotivation_4",
        "RDMPR12/5":"docMotivation_5",
        "RDMPR12/6":"docMotivation_6",
        "RDMPR12/other":"docMotivation_other",
        "RDMPR11/0":"docObstacles_0",
        "RDMPR11/1":"docObstacles_1",
        "RDMPR11/2":"docObstacles_2",
        "RDMPR11/3":"docObstacles_3",
        "RDMPR11/4":"docObstacles_4",
        "RDMPR11/5":"docObstacles_5",
        "RDMPR11/6":"docObstacles_6",
        "RDMPR11/7":"docObstacles_7",
        "RDMPR11/8":"docObstacles_8",
        "RDMPR11/9":"docObstacles_9",
        "RDMPR11/other":"docObstacles_other",
        "SERVC1/0":"servNeeds_sub_0",
        "SERVC1/1":"servNeeds_sub_1",
        "SERVC1/2":"servNeeds_sub_2",
        "SERVC1/3":"servNeeds_sub_3",
        "SERVC1/4":"servNeeds_sub_4",
        "SERVC1/5":"servNeeds_sub_5",
        "SERVC1/6":"servNeeds_sub_6",
        "SERVC1/7":"servNeeds_sub_7",
        "SERVC1/8":"servNeeds_sub_8",
        "SERVC1/9":"servNeeds_sub_9",
        "SERVC1/other":"servNeeds_sub_other",
        "SERVC2/1":"servFormat_1",
        "SERVC2/2":"servFormat_2",
        "SERVC2/3":"servFormat_3",
        "SERVC2/4":"servFormat_4",
        "SERVC2/5":"servFormat_5",
        "SERVC2/6":"servFormat_6",
        "SERVC3":"feedback"
        }

##########################################
############### DICTIONARY ###############
###### DEFINE DATA TYPES OF COLUMNS ######
########################################## 

### for categorical, numerical and string answers

HCS_dtypesWOmc = {
        "centerAffiliation":"category",
        "researchFieldHGF":"category",
        "researchArea":"category",
        "researchAreaING":"category",
        "researchAreaGEO":"category",
        "researchAreaMATH":"category",
        "researchAreaPHYS":"category",
        "researchAreaLIFE":"category",
        "researchAreaBIO":"category",
        "researchAreaMED":"category",
        "researchAreaAGRI":"category",
        "researchAreaPSYCH":"category",
        "researchAreaCHEM":"category",
        "yearsInResearch":"category",
        "dataInPublication":"category",
        "dataAmount_lsf":"float64",
        "pubAmount":"float64",
        "careerLevel":"category",
        "orcid":"category",
        "fairFamiliarity":"category",
        "dataOrigin_MeasVsSim":"category",
        "dataOrigin_SelvVsReuse":"category",
        "dataGatherTime":"float64",
        "experimentDuration_sub":"category",
        "dataAnalDuration_sub":"category",
        "longtermStorage":"category",
        "docStructured":"category",
        "docDefSchema":"category",
        "servFormat_1":"category",
        "servFormat_2":"category",
        "servFormat_3":"category",
        "servFormat_4":"category",
        "servFormat_5":"category",
        "servFormat_6":"category",
        "startlanguage":"category",
        "lastpage":"category"
        }


###############################################
#################### LIST #####################
###### SPECIFY MULTIPLE CHOICE QUESTIONS ######
############################################### 

# List  to specify all multiple choice questions
# For MC question cleaning
# List includes common strings of MC question column names

HCS_MCList = [
        "dataGenMethod_", 
        "lsfIdent_", 
        "dataFormats_",
        "pubMethod_", 
        "pubMotivation_", 
        "pubObstaclesA_",
        "pubObstaclesB_",
        "pubMetadata_", 
        "docMethod_", 
        "docMetadata_", 
        "docMotivation_", 
        "docStandards_", 
        "docObstacles_", 
        "servNeeds_sub_",
        "RSDP2",
        "RSDP1c",
        "RSDP3",
        "DTPUB1b",
        "DTPUB3",
        "DTPUB4a",
        "DTPUB4b",
        "DTPUB7",
        "RDMPR3",
        "RDMPR7",
        "RDMPR12",
        "RDMPR6",
        "RDMPR11",
        "SERVC1"
        ]

##########################################
############### DICTIONARY ###############
########### CONVERT TO BOOLEAN ###########
##########################################

# Dictionary to convert MC answers to dtype = 'boolean'
# In this case, MC questions were exported with 'Yes'/'No' answers 

convertToBoolDict = {
        'Y':True,
        'N':False
        }

####################################################
#################### DICTIONARY ####################
########### ABBREVIATED HGF CENTER NAMES ###########
####################################################

# Dictionary to abbreviate center names in seperate column
# facilitates data handling

abbrevCenterAffilDict  = {
 'Alfred-Wegener-Institute (AWI)':"AWI",
 'Deutsches Elektronen-Synchrotron (DESY)':"DESY",
 'Forschungszentrum Jülich (FZJ)':"FZJ",
 'German Aerospace Center (DLR)':"DLR",
 'German Cancer Research Center (DKFZ)':"DKFZ",
 'German Center for Neurodegenerative Diseases (DZNE)':"DZNE",
 'German Research Centre for Geosciences (GFZ)':"GFZ",
 'Helmholtz Center for Information Security (CISPA)':"CISPA",
 'Helmholtz Centre for Environmental Research (UFZ)':"UFZ",
 'Helmholtz Centre for Heavy Ion Research (GSI)':"GSI",
 'Helmholtz Centre for Infection Research (HZI)':"HZI",
 'Helmholtz Centre for Ocean Research Kiel (GEOMAR)':"GEOMAR",
 'Helmholtz Zentrum München - German Research Center for Environmental Health (HMGU)':"HMGU",
 'Helmholtz-Zentrum Berlin für Materialien und Energie (HZB)':"HZB",
 'Helmholtz-Zentrum Dresden-Rossendorf (HZDR)':"HZDR",
 'Helmholtz-Zentrum Hereon':"Hereon",
 'Karlsruhe Institute of Technology (KIT)':"KIT",
 'Max Delbrück Center for Molecular Medicine in the Helmholtz Association (MDC)':"MDC",
 'Other':"Other"}


#######################################################
###################### DICTIONARY #####################
########### ABBREVIATED HGF RESEARCH FIELDS ###########
#######################################################

# Dictionary to abbreviate HGF research fields in seperate column
# abbreviated research Fields = HMC HUBS

abbrevHubsDict = {
    'Aeronautics, Space and Transportation':"AST",
    'Earth and Environment':"E&E",
    'Energy':"Energy",
    'Health':"Health",
    'Information':"Info",
    'Matter':"Matter"
        }


#######################################################
###################### DICTIONARY #####################
############## MULTIPLE CHOICE QUESTIONS ##############
##################### SUBQUESTIONS ####################
#######################################################

# Dictionary specifying the subquestions of multiple choice questions
 
HCS_MCsubquestions = {
        "dataFormats_":{"dataFormats_1":"archives",
                        "dataFormats_2":"audiovisual \n formats",
                        "dataFormats_3":"configurations",
                        "dataFormats_4":"databases",
                        "dataFormats_5":"images",
                        "dataFormats_6":"network-based data",
                        "dataFormats_7":"plain text",
                        "dataFormats_8":"device-specific \n data formats",
                        "dataFormats_9":"statistical \n data formats",
                        "dataFormats_10":"application-specific \n formats",
                        "dataFormats_11":"source code",
                        "dataFormats_12":"office applications",
                        "dataFormats_13":"structured graphics",
                        "dataFormats_14":"structured text",
                        "dataFormats_15":"binary scientific \n formats"
                        },
            
            "dataGenMethod_":{'dataGenMethod_1':"imaging",
                              'dataGenMethod_2':"analytical methods",
                              'dataGenMethod_3':"simulations",
                              'dataGenMethod_4':"sample synthesis and preparation",
                              'dataGenMethod_5':"cohort studies",
                              'dataGenMethod_6':"recordings",
                              'dataGenMethod_other':"other"
                              },
                              
            "dataStorage_":{'dataStorage_0':"I don't know.", 
                            'dataStorage_1':"locally", 
                            'dataStorage_2':"centrally \n (internal server)",
                            'dataStorage_3':"externally \n (servers / repositories)"
                            },
                                                       
            "docMetadata_":{'docMetadata_2':"contextual information",
                            'docMetadata_3':"provenance of data",
                            'docMetadata_4':"information on data collection",
                            'docMetadata_5':"data processing and analysis",
                            'docMetadata_6':"description of data structure",
                            'docMetadata_7':"legal conditions",
                            'docMetadata_8':"information on storage \n and long-term preservation",
                            'docMetadata_9':"access information"
                            },
                         
            "docMethod_":{'docMethod_0':"no documentation", 
                          'docMethod_1':"pen and paper", 
                          'docMethod_2':"digital system", 
                          'docMethod_3':"digital text"
                          },
                         
            "docMotivation_":{'docMotivation_0':"no specific reason",
                              'docMotivation_1':"improved findability",
                              'docMotivation_2':"provide research \n data context",
                              'docMotivation_3':"improved reproducibility \n of workflows",
                              'docMotivation_4':"facilitate data publication",
                              'docMotivation_5':"scientific community \n recognition",
                              'docMotivation_6':"administrative guidelines"
                              },
                              
            "docObstacles_":{'docObstacles_0':"no difficulties",
                             'docObstacles_1':"lack of resources",
                             'docObstacles_4':"lack of incentives",
                             'docObstacles_5':"lack of technical knowledge",
                             'docObstacles_6':"lack of technical solutions",
                             'docObstacles_7':"legal / ethical inscurities",
                             'docObstacles_8':"no apparent benefits.",
                             'docObstacles_9':"lack of experience"
                            },
                             
            "docStandards_":{'docStandards_1':"DataCite",
                             'docStandards_10':"MiAIRR",
                             'docStandards_11':"MIBBI",
                             'docStandards_12':"MIABE",
                             'docStandards_13':"DDI",
                             'docStandards_14':"PREMIS",
                             'docStandards_15':"OEO",
                             'docStandards_16':"IEC standards",
                             'docStandards_17':"Brick",
                             'docStandards_18':"CityGML",
                             'docStandards_19':"IFC",
                             'docStandards_2':"Dublin Core",
                             'docStandards_20':"SSN / SOS",
                             'docStandards_21':"QUDT",
                             'docStandards_22':"NetCDF",
                             'docStandards_23':"SSN / SensorML",
                             'docStandards_24':"PROV-O",
                             'docStandards_25':"CIF",
                             'docStandards_26':"CSMD",
                             'docStandards_3':"DCAT",
                             'docStandards_4':"ISO-Standards",
                             'docStandards_5':"NeXus",
                             'docStandards_6':"MIAME",
                             'docStandards_7':"MINSEQ",
                             'docStandards_8':"MIxS",
                             'docStandards_9':"Darwin Core"
                             },
                             
            "lsfIdent_":{'lsfIdent_1':"LHC",
                         'lsfIdent_10':"SIS18",
                         'lsfIdent_11':"ESR",
                         'lsfIdent_2':"PETRA III",
                         'lsfIdent_3':"BESSY II",
                         'lsfIdent_4':"KATRIN",
                         'lsfIdent_5':"ELBE",
                         'lsfIdent_6':"BER II",
                         'lsfIdent_7':"FLASH",
                         'lsfIdent_8':"European XFEL",
                         'lsfIdent_9':"UNILAC"
                         },
                         
            "pubMetadata_":{'pubMetadata_0':"none",
                            'pubMetadata_1':"all of them",
                            'pubMetadata_21':"name of data set",
                            'pubMetadata_22':"(Persistent) Identifier",
                            'pubMetadata_23':"research subject",
                            'pubMetadata_24':"research method",
                            'pubMetadata_31':"author / producer of the data",
                            'pubMetadata_32':"acquisition location",
                            'pubMetadata_33':"collection data / period",
                            'pubMetadata_41':"devices used",
                            'pubMetadata_42':"device parameters used",
                            'pubMetadata_43':"data collection software",
                            'pubMetadata_44':"data collection workflows",
                            'pubMetadata_51':"analysis software / scripts",
                            'pubMetadata_52':"data analysis procedure",
                            'pubMetadata_61':"details on data formats",
                            'pubMetadata_62':"variable description",
                            'pubMetadata_71':"licensing information",
                            'pubMetadata_72':"access rights",
                            'pubMetadata_81':"retention period",
                            'pubMetadata_82':"backup strategies",
                            'pubMetadata_83':"sample storage conditions",
                            'pubMetadata_91':"API description",
                            'pubMetadata_92':"logs / statistics",
                            'pubMetadata_93':"registration procedures"
                            },
                            
            "pubMethod_":{'pubMethod_1':"supplementary to \n journal publication", 
                          'pubMethod_2':"in repository", 
                          'pubMethod_3':"data journal"
                          },
                          
            "pubMotivation_":{'pubMotivation_1':"reusability",
                              'pubMotivation_2':"visibility",
                              'pubMotivation_3':"publication statistics",
                              'pubMotivation_4':"gudelines / policies",
                              'pubMotivation_5':"good scientific practice",
                              'pubMotivation_6':"collaboration",
                              'pubMotivation_7':"financial benefits"
                              },
                              
            "pubObstaclesA_":{'pubObstaclesA_0':"no obstacles",    
                             'pubObstaclesA_1':"costs too high",
                             'pubObstaclesA_2':"lack of time / personnel",
                             'pubObstaclesA_3':"lack of incentives",
                             'pubObstaclesA_4':"possibility of data \n misinterpretation / misuse",
                             'pubObstaclesA_5':"technical barriers",
                             'pubObstaclesA_6':"legal / ethical concerns",
                             'pubObstaclesA_7':"technical support needed"
                             },
                              
            "pubObstaclesB_":{'pubObstaclesB_0':"no data to publish",
                              'pubObstaclesB_1':"costs too high",
                              'pubObstaclesB_2':"lack of time / personnel",
                              'pubObstaclesB_3':"lack of incentives",
                              'pubObstaclesB_4':"possibility of data \n misinterpretation / misuse",
                              'pubObstaclesB_5':"technical barriers",
                              'pubObstaclesB_6':"legal / ethical concerns",
                              'pubObstaclesB_7':"technical support needed"
                              }, 
            
            "servNeeds_sub_":{'servNeeds_sub_0':"no need for support",
                              'servNeeds_sub_1':"data publication",
                              'servNeeds_sub_2':"research data reuse",
                              'servNeeds_sub_3':"DMP development",
                              'servNeeds_sub_4':"metadata enrichment \n of research data",
                              'servNeeds_sub_5':"RDM software & tools",
                              'servNeeds_sub_6':"metadata use & analysis",
                              'servNeeds_sub_7':"legal aspects",
                              'servNeeds_sub_8':"best practices",
                              'servNeeds_sub_9':"technical aspects of RDM"
                              }
        }



#######################################################
###################### DICTIONARY #####################
############## ORDERED CATEGORICAL VALUES #############
#######################################################

HCS_orderedCats = {
        "yearsInResearch":['No degree', 
                           'Less than 1 year', 
                           '1 to 3 years', 
                           '4 to 6 years', 
                           '7 to 10 years', 
                           'More than 10 years'],
        "careerLevel":['Student', 
                       'PhD candidate', 'Postdoc', 
                       'Research Associate', 
                       'Principal Investigator', 
                       'Technical Staff', 
                       'Other'],
        "dataInPublication":['< 100 MB',
                             '100 MB - 1000 MB (1 GB)', 
                             '1 GB - 10 GB', 
                             '10 GB - 100 GB', 
                             '100 GB - 1000 GB (1 TB)',
                             '> 1 TB',
                             'I don\'t know'],
        "experimentDuration_sub":['Less', 
                                  'As much', 
                                  'More', 
                                  'I don\'t know'],
        "dataAnalDuration_sub":['Less', 
                                  'As much', 
                                  'More', 
                                  'I don\'t know'],
 'dataAmount_lsf': [0.0, 5.0, 10.0, 15.0, 20.0, 25.0, 30.0, 35.0, 40.0, 45.0, 50.0, 55.0, 60.0, 65.0,
                    70.0, 75.0, 80.0, 85.0, 90.0, 95.0, 100.0],
 'pubAmount': [0.0, 5.0, 10.0, 15.0, 20.0, 25.0, 30.0, 35.0, 40.0, 45.0, 50.0, 55.0, 60.0, 65.0,
                    70.0, 75.0, 80.0, 85.0, 90.0, 95.0, 100.0],
'dataGatherTime': [1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 8.0, 9.0, 10.0, 12.0, 18.0, 24.0, 36.0, 48.0],
# The rest is autogenerated, to do not compute them during dashboard runtime
'pubMethod_1': [True],
 'pubMethod_2': [True],
 'pubMethod_3': [True],
 'pubMethod_other': ['In repository',
  'Other',
  'Supplementary to journal publication'],
 'pubMotivation_1': [True],
 'pubMotivation_2': [True],
 'pubMotivation_3': [True],
 'pubMotivation_4': [True],
 'pubMotivation_5': [True],
 'pubMotivation_6': [True],
 'pubMotivation_7': [True],
 'pubMotivation_other': ['Guidelines / policies of publishers',
  'Good scientific practice',
  'Reusability',
  'Other',
  'Guidelines/policies of institute/funder'],
 'pubObstaclesA_0': [True],
 'pubObstaclesA_1': [True],
 'pubObstaclesA_2': [True],
 'pubObstaclesA_3': [True],
 'pubObstaclesA_4': [True],
 'pubObstaclesA_5': [True],
 'pubObstaclesA_6': [True],
 'pubObstaclesA_7': [True],
 'pubObstaclesA_other': ['Legal / ethical concerns',
  'Lack of time / personnel',
  'Technical barriers',
  'Technical support needed',
  'Other',
  'Competition',
  'Insufficiently trained',
  'Lack of incentives',
  'No value to others'],
 'pubObstaclesB_0': [True],
 'pubObstaclesB_1': [True],
 'pubObstaclesB_2': [True],
 'pubObstaclesB_3': [True],
 'pubObstaclesB_4': [True],
 'pubObstaclesB_5': [True],
 'pubObstaclesB_6': [True],
 'pubObstaclesB_7': [True],
 'pubObstaclesB_other': ['No value to others',
  'Legal / ethical concerns',
  'Other',
  'Lack of incentives',
  'Insufficiently trained',
  'Competition',
  'Technical support needed'],
 'pubRepo_1': ['Institutional Repository',
  'Zenodo',
  'Gitlab / GitHub',
  'GEO',
  'WDCC',
  'PANGAEA',
  'ENA',
  'OSF',
  'RCSB PDB',
  'Copernicus Open Access Hub',
  'EGA',
  'Materials Cloud',
  'figshare',
  'ProteomeXchange',
  'FIZ Karlsruhe',
  'BMRB',
  'IRRMC',
  'OpenOrganelle',
  'IMPC',
  'PUBLISSO',
  'EudraCT',
  'FAIRDOMHub',
  'ArrayExpress',
  'GLIMS',
  'Other',
  'CDDIS',
  'DataONE',
  'Open Energy Platform',
  'HEPData'],
 'pubRepo_2': ['Gitlab / GitHub',
  'Zenodo',
  'Institutional Repository',
  'Other',
  'PANGAEA',
  'figshare',
  'SRA',
  'ENA',
  'iReceptor',
  'dbGAP',
  'HEASARC',
  'GenTaR',
  '4DN',
  'ClinicalTrials.gov',
  'GEO',
  'NSSDC',
  'ArrayExpress',
  'MetaboLights',
  'Open Energy Platform',
  'WDCC',
  'ePrints Soton',
  'ProteomeXchange',
  'EMDB',
  'CDMS'],
 'pubRepo_3': ['Gitlab / GitHub',
  'Zenodo',
  'EMPIAR',
  'ESA Data Archive',
  'BKG',
  'PANGAEA',
  'B2SHARE',
  'WDCC',
  'Other',
  'figshare',
  'ProteomeXchange',
  'UCSC Genome Browser',
  'Institutional Repository'],
 'pubRepo_4': ['TERENO',
  'Institutional Repository',
  'AIRR Data Commons (ADC)'],
 'pubRepo_5': ['GIN'],
 'pubMetadata_1': [True],
 'pubMetadata_21': [True],
 'pubMetadata_22': [True],
 'pubMetadata_23': [True],
 'pubMetadata_24': [True],
 'pubMetadata_31': [True],
 'pubMetadata_32': [True],
 'pubMetadata_33': [True],
 'pubMetadata_41': [True],
 'pubMetadata_42': [True],
 'pubMetadata_43': [True],
 'pubMetadata_44': [True],
 'pubMetadata_51': [True],
 'pubMetadata_52': [True],
 'pubMetadata_61': [True],
 'pubMetadata_62': [True],
 'pubMetadata_71': [True],
 'pubMetadata_72': [True],
 'pubMetadata_81': [True],
 'pubMetadata_82': [],
 'pubMetadata_83': [True],
 'pubMetadata_91': [True],
 'pubMetadata_92': [True],
 'pubMetadata_93': [],
 'pubMetadata_other': ['Others', 'Scope of data set'],
 'pubMetadata_0': [True],
 'centerAffiliation': ['Anonymized'],
 'centerAffiliation_other': ['Anonymized'],
 'researchFieldHGF': ['Aeronautics, Space and Transportation',
  'Matter',
  'Energy',
  'Health',
  'Earth and Environment',
  'Information'],
 'researchArea': ['Engineering Science',
  'Physics',
  'Life Science',
  'Earth Science',
  'Chemistry',
  'Computer Science',
  'Psychology',
  'Mathematics'],
 'researchArea_other': ['Informatik',
  'Computer Science',
  'Transportation',
  'Epidemiology',
  'Bioinformatics',
  'Data Science',
  'Epidemiologie',
  'Datenwissenschaften',
  'Medizin',
  'Biowissenschaften',
  'Energieforschung',
  'Medizininformatik',
  'Biomedical Engineering',
  'Data management',
  'Beschleunigerphysik',
  'material science',
  'Ecologie',
  'Technology Assessment',
  'Biologie',
  'Verkehrswissenschaften',
  'Umwelt',
  'Robotik',
  'Materialwissenschaften',
  'Systemanalyse',
  '(Energie-)Wirtschaftswissenschaften',
  'Energy system modeling',
  'materials science',
  'Materials Science',
  'MTRA'],
 'researchAreaAGRI': ['Plant Breeding'],
 'researchAreaAGRI_other': [],
 'researchAreaBIO': ['Molecular Biology',
  'Cell Biology',
  'Bioinformatics',
  'Physiology',
  'Chemical Biology',
  'Computational Biology',
  'Biomedical Science',
  'Systems Biology',
  'Biochemistry',
  'Microbiology',
  'Human Biology',
  'Ecology',
  'Genetics',
  'Structural Biology',
  'Biophysics',
  'Radiobiology'],
 'researchAreaBIO_other': ['Immunology', 'Genomik', 'Neurobiologie'],
 'researchAreaCHEM': ['Physical Chemistry',
  'Polymer Research',
  'Analytical Chemistry',
  'Technical Chemistry',
  'Geochemistry',
  'Theoretical Chemistry',
  'Biomimetic Chemistry',
  'Biochemistry',
  'Cheminformatics'],
 'researchAreaCHEM_other': ['Radiochemie',
  'Material chemistry',
  'Radiochemistry',
  'Electrochemistry',
  'Radiation Chemistry'],
 'researchAreaGEO': ['Atmospheric Science',
  'Environmental Science',
  'Geography',
  'Geology',
  'Geophysics',
  'Oceanography',
  'Water Research',
  'Soil Science'],
 'researchAreaGEO_other': ['Erdbeobachtung',
  'Geoanalytik',
  'Geochemie',
  'Remote Sensing',
  'Geodäsie',
  'Klimatologie',
  'Fernerkundung',
  'Planetenforschung',
  'Urban'],
 'researchAreaING': ['Aerospace Engineering',
  'Energy Engineering',
  'Electrical Engineering',
  'Materials Engineering',
  'Mechanical Engineering',
  'Process Engineering',
  'Industrial Engineering',
  'Systems Engineering'],
 'researchAreaING_other': ['Softwareentwicklung',
  'Umweltwissenschaften',
  'Batteriematerialien',
  'Materialwissenschaften',
  'Robotik',
  'Fahrzeugtechnik',
  'Logistik/Verkehr',
  'Verkehrswesen'],
 'researchAreaLIFE': ['Biology', 'Medicine', 'Health Science', 'Agriculture'],
 'researchAreaLIFE_other': ['Verkehrsforschung',
  'Biotechnology + Automation',
  'Biochemie'],
 'researchAreaMATH': ['Applied Mathematics', 'Statistics'],
 'researchAreaMATH_other': ['Data Science'],
 'researchAreaMED': ['Neurology',
  'Oncology',
  'Infectious Disease Medicine',
  'Cardiology',
  'Medical Informatics',
  'Psychiatry',
  'Pediatrics',
  'Pharmacy',
  'Radiobiology',
  'Gynecology',
  'Hematology'],
 'researchAreaMED_other': [],
 'researchAreaPHYS': ['Condensed Matter Physics',
  'Particles, Nuclei and Fields',
  'Atomic, Molecular, Optical and Plasma Physics',
  'Meteorology',
  'Soft Matter Physics',
  'Nanotechnology',
  'Astrophysics and Astronomy',
  'Biophysics',
  'Thermodynamics',
  'Polymer Physics'],
 'researchAreaPHYS_other': ['Accelerator physics',
  'Quanteninformation',
  'space physics',
  'Beschleunigerphysik',
  'Accelerator Physics',
  'Multiple areas crossing over physics, biology and material science',
  'Beschleuniger',
  'Angewandte Kernphysik',
  'Quantum Information',
  'X-ray Imaging',
  'Materialanalyse',
  'medical physics',
  'Medizinische Physik',
  'Medical',
  'Medical physics',
  'Atmosphere',
  'Space Weather',
  'Röntgenoptik'],
 'researchAreaPSYCH': ['Industrial and Organisational Psychology'],
 'researchAreaPSYCH_other': ['Human Factors',
  'Kognitive Psychologie',
  'Engineering Psychology / Human Factors',
  'Ingenieurpsychologie',
  'Ingenieurspsychologie',
  'Verkehrspsychologie',
  'Experimentelle Psychologie'],
 'careerLevel_other': ['Principal Investigator',
  'Technical Staff',
  'Research Associate',
  'Postdoc',
  'Other'],
 'orcid': ['Yes', 'No', 'Not sure'],
 'fairFamiliarity': ['Not familiar with FAIR',
  'Familiar with FAIR',
  'Apply FAIR'],
 'dataStorage_1': [True],
 'dataStorage_2': [True],
 'dataStorage_3': [True],
 'dataStorage_0': [True],
 'dataStorage_other': ['Centrally (internal server)',
  'Most data is lost',
  'Externally (servers / repositories)',
  'Locally',
  'Other'],
 'software_1': ['Anonymized',
  'Python',
  'MATLAB / Simulink',
  'R',
  'Excel (Spreadsheets)',
  'OriginLab',
  'Office Software (unspecified)',
  'ROOT framework',
  'LabVIEW',
  'Fortran',
  'IGOR',
  'Jupyter',
  'SPSS',
  'C/C++',
  'Git',
  'Fiji',
  'Visual Studio',
  'CATIA CAD-software',
  'Database Management System',
  'COMSOL Multiphysics',
  'QGIS/GDAL',
  'emacs',
  'Dymola',
  'PTC Creo',
  'FactSage',
  'SAS',
  'gcc',
  'Word',
  'ANSYS',
  'AiiDA',
  'Tecplot',
  'Linux',
  'IDL',
  'ImageJ',
  'FlowJo',
  'Mathematica',
  'FLUKA',
  'TRACE',
  'ZEMAX',
  'Paraview',
  'Aspen Custom Modeler',
  'GraphPad',
  'OpenFOAM',
  'cdo',
  'Altium Designer',
  'OpenCV',
  'Machine Learning Libraries',
  'Command line (scripts)',
  'MITK',
  'Adobe Illustrator',
  'Delphi',
  'CFD Software (e.g. TecPlot, ParaView)',
  'ArcGIS'],
 'software_2': ['Anonymized',
  'Python',
  'Excel (Spreadsheets)',
  'MATLAB / Simulink',
  'OriginLab',
  'R',
  'LabVIEW',
  'Office Software (unspecified)',
  'Git',
  'Database Management System',
  'GraphPad',
  'QGIS/GDAL',
  'Command line (scripts)',
  'C/C++',
  'LaTeX',
  'Visual Studio',
  'Tecplot',
  'Jupyter',
  'ROOT framework',
  'IGOR',
  'Altium Designer',
  'Word',
  'Fortran',
  'Mathematica',
  'IDL',
  'ImageJ',
  'Paraview',
  'PyTorch',
  'ANSYS',
  'Machine Learning Libraries',
  'Linux',
  'Notepad++',
  'ArcGIS',
  'Google Earth Engine',
  'CATIA CAD-software',
  'Java',
  'OpenFOAM',
  'Adobe Illustrator',
  'cdo',
  'TRACE',
  'SPSS',
  'MITK',
  'gnuplot',
  'OpenCV',
  'SAS',
  'CFD Software (e.g. TecPlot, ParaView)',
  'gcc',
  'Delphi',
  'FlowJo',
  'AiiDA'],
 'software_3': ['Anonymized',
  'Python',
  'Excel (Spreadsheets)',
  'Office Software (unspecified)',
  'MATLAB / Simulink',
  'OriginLab',
  'LaTeX',
  'LabVIEW',
  'Word',
  'PowerPoint',
  'ImageJ',
  'QGIS/GDAL',
  'Git',
  'R',
  'Database Management System',
  'C/C++',
  'ANSYS',
  'gnuplot',
  'Fiji',
  'Jupyter',
  'SPSS',
  'Visual Studio',
  'Tecplot',
  'EPLAN',
  'Command line (scripts)',
  'Linux',
  'Adobe Illustrator',
  'Notepad++',
  'Fortran',
  'Java',
  'CFD Software (e.g. TecPlot, ParaView)',
  'Machine Learning Libraries',
  'IDL',
  'MITK',
  'Mathematica',
  'Delphi',
  'GraphPad',
  'AiiDA',
  'FLUKA',
  'ROOT framework',
  'OpenCV',
  'ZEMAX',
  'ArcGIS',
  'Google Earth Engine',
  'IGOR',
  'COMSOL Multiphysics',
  'Aspen Custom Modeler',
  'emacs',
  'cdo',
  'Paraview',
  'FlowJo',
  'PyTorch',
  'CATIA CAD-software'],
 'docObstacles_0': [True],
 'docObstacles_1': [True],
 'docObstacles_4': [True],
 'docObstacles_5': [True],
 'docObstacles_6': [True],
 'docObstacles_7': [True],
 'docObstacles_8': [True],
 'docObstacles_9': [True],
 'docObstacles_other': ['Lack of technical solutions',
  'Relevant metadata is missing',
  'Heterogeneous workflows complicate standardized solutions',
  'Lack of resources',
  'Other',
  'Commercial applications complicate standardized solutions',
  'Lack of technical knowledge'],
 'docMotivation_1': [True],
 'docMotivation_2': [True],
 'docMotivation_3': [True],
 'docMotivation_4': [True],
 'docMotivation_5': [True],
 'docMotivation_6': [True],
 'docMotivation_0': [True],
 'docMotivation_other': ['Improved working with data',
  'Improved collaborations',
  'Provide research data context',
  'Use of Standard'],
 'docMethod_1': [True],
 'docMethod_2': [True],
 'docMethod_3': [True],
 'docMethod_other': ['Source code and scripts',
  'GitLab',
  'Digital text',
  'Digital system',
  'Other'],
 'docMethod_0': [True],
 'docStructured': ['No', 'Yes', 'Not sure'],
 'docDefSchema': ['No', 'Yes', 'Not sure'],
 'docStandards_1': [True],
 'docStandards_2': [True],
 'docStandards_3': [],
 'docStandards_4': [True],
 'docStandards_5': [True],
 'docStandards_6': [True],
 'docStandards_7': [True],
 'docStandards_8': [True],
 'docStandards_9': [True],
 'docStandards_10': [True],
 'docStandards_11': [],
 'docStandards_12': [],
 'docStandards_13': [],
 'docStandards_14': [],
 'docStandards_15': [True],
 'docStandards_16': [True],
 'docStandards_17': [],
 'docStandards_18': [True],
 'docStandards_19': [True],
 'docStandards_20': [True],
 'docStandards_21': [True],
 'docStandards_22': [True],
 'docStandards_23': [True],
 'docStandards_24': [True],
 'docStandards_25': [True],
 'docStandards_26': [True],
 'docStandards_other': ['No standard',
  'Others',
  'MIFlowCyt',
  'PubData',
  'CF Metadata Conventions',
  'iFDO',
  'BIDS',
  'MIAME',
  'DICOM',
  'openPMD',
  'PDBx/mmCIF'],
 'docMetadata_2': [True],
 'docMetadata_3': [True],
 'docMetadata_4': [True],
 'docMetadata_5': [True],
 'docMetadata_6': [True],
 'docMetadata_7': [True],
 'docMetadata_8': [True],
 'docMetadata_9': [True],
 'docMetadata_other': ['Information on data collection',
  'Instructions for reuse',
  'Description of data structure',
  'Others',
  'Data processing and analysis'],
 'docDigital_2': ['All', 'Some of them', 'None'],
 'docDigital_3': ['All', 'Some of them', 'None'],
 'docDigital_4': ['All', 'Some of them', 'None'],
 'docDigital_5': ['All', 'Some of them', 'None'],
 'docDigital_6': ['All', 'Some of them'],
 'docDigital_7': ['All', 'Some of them', 'None'],
 'docDigital_8': ['All', 'Some of them', 'None'],
 'docDigital_9': ['All', 'Some of them', 'None'],
 'docDigital_other': ['All', 'Some of them'],
 'docAuto_2': ['None', 'Some of them', 'All'],
 'docAuto_3': ['None', 'Some of them', 'All'],
 'docAuto_4': ['None', 'Some of them', 'All'],
 'docAuto_5': ['None', 'Some of them', 'All'],
 'docAuto_6': ['None', 'Some of them', 'All'],
 'docAuto_7': ['None', 'Some of them', 'All'],
 'docAuto_8': ['None', 'Some of them', 'All'],
 'docAuto_9': ['Some of them', 'None', 'All'],
 'docAuto_other': ['None', 'Some of them', 'All'],
 'dataOrigin_MeasVsSim': ['Mostly measured',
  'Purely measured',
  'Equally measured and simulated',
  'Mostly simulated',
  'Purely simulated'],
 'dataOrigin_SelvVsReuse': ['Mostly generated',
  'Purely generated',
  'Mostly reused',
  'Equally generated and reused',
  'Purely reused'],
 'longtermStorage': ['Yes', 'Not sure', 'No'],
 'lsfIdent_1': [True],
 'lsfIdent_2': [True],
 'lsfIdent_3': [True],
 'lsfIdent_4': [],
 'lsfIdent_5': [True],
 'lsfIdent_6': [True],
 'lsfIdent_7': [True],
 'lsfIdent_8': [True],
 'lsfIdent_9': [True],
 'lsfIdent_10': [True],
 'lsfIdent_11': [True],
 'lsfIdent_other': ['Anonymized'],
 'dataGenMethod_1': [True],
 'dataGenMethod_2': [True],
 'dataGenMethod_3': [True],
 'dataGenMethod_4': [True],
 'dataGenMethod_5': [True],
 'dataGenMethod_6': [True],
 'dataGenMethod_other': ['Other',
  'Analytical methods',
  'Recordings',
  'Cohort studies',
  'Simulations',
  'Sample synthesis and preparation'],
 'dataGenMethodSpec_1_1': ['Mikroskopie',
  'MRI',
  'Microscopy',
  'MRT',
  'AFM',
  'SEM',
  'Fluoreszenzmikroskopie',
  'PET',
  'microscopy',
  'Fluorescence Microscopy',
  'Röntgendiffraktion',
  'REM',
  'Satellitendaten',
  'Lichtmikroskopie',
  'Photoemissionsmikroskopie (PEEM)',
  'transmission electron microscopy',
  'Light microscope',
  'Photoemissionsmkroskopie',
  'Proteinkristallographie',
  'Confocal Microscopy',
  'Segmentierung',
  'phase-contrast',
  'Kameras',
  'Scanning Electron Microscopy',
  'Filtering',
  'Transmissionselektronenmikroskopie',
  'µCT',
  'Immunfluorescence microscopy',
  'Confocal microscopy',
  'Multiphotonen Mikroskopie',
  '2P calcium imaging',
  'Three-Dimensional X-ray Diffraction',
  'Crystallography/diffraction/MX',
  'Rasterelektronenmikroskopie',
  'Kamera snapshots',
  'Röntgen-Holografie',
  'X-ray imagry',
  'Digitalfotografie, Kameras',
  'Bright field color & fluorescent',
  'matlap',
  'konfokales Mikroskop',
  'Flluoreszenz-Mikroskopie, Lebendzellmikroskopie',
  'screencopy',
  'Photoemissions Elektronen Mikroskopie',
  'ATLAS detector',
  'Electron imaging on screen',
  'Full-field X-ray tomography',
  'PCI',
  'CDI',
  'Velocity map imaging (VMI)',
  'Beam-characterization of electron-sources using screens & cameras',
  'coherent diffraction imaging (CDI)',
  'X-ray Coherent Imaging',
  'confokale Mikroskopie',
  'Helium Ionen Mikroskopie',
  'STXM',
  'electron microscopy',
  'MR-Tomographie',
  'CT',
  'Satellite',
  'Image analysis of photographs',
  'RGB-Kameras',
  'Wetterradar',
  'Satellitenbilder',
  'synthetic aperture radar signal processing',
  '(Fluoreszenz)mikroskopie',
  'Underwater photo / video by marine robots',
  'digital processing',
  'Mikroskpie',
  'Satellitendaten(Höhenmodelle, Landuse etc.)',
  'Strukturelle Magnetresonanztomographie (MRT)',
  'Tomography',
  'Tomographie (CT/MR)',
  'yes',
  'Synchrotron microCT',
  'Bildauswertung',
  'Cryoelectron Microscopy',
  'Kamerabilder',
  'Lidar',
  'Tomographie',
  'Reflectance imaging',
  'Remote sensing',
  'Hochdurchsatz-Mikroskopie von fixierten Zellen',
  'western blot, microscopy',
  'FACS',
  'Ptychography',
  'fMRI',
  'pQCT',
  'CCD camera',
  'Fluoreszenz-Mikroskopie',
  'IR Tomographie',
  'remote sensing, air borne, satellite',
  'Satellite images processing',
  'Statistische Verfahren',
  'Instrument',
  'remote sensing',
  'SAR Satellitendaten',
  'satellite-based imaging',
  'satellitengestützte Erdbeobachtung',
  'Fernerkundungssensoren',
  'Pixel Detetors'],
 'dataGenMethodSpec_1_2': ['MRT',
  'PET',
  'TEM',
  'Elektronenmikroskopie',
  'CT',
  'Mikroskopie',
  'Ptychography',
  'X-ray',
  'REM',
  'Immunofluorescence',
  'SEM',
  'Focused ion beam electron microscopy',
  'Optical Microscopy',
  'Tomographie',
  'LSM',
  'Rasterkraftmikroskopie',
  'Transmission Electron Microscope',
  'OCT',
  'TIRF',
  'Objekterkennung',
  'Flurescent microscopy',
  'Laser Microscopy',
  'Lichtmikroskopie',
  'Coherent imaging/diffraction',
  'optical microscopy',
  'THz source characterization',
  'Computing the covariance images/maps between VMI and mass spectrum',
  'CDI',
  'Transmission X-ray microscopy',
  'Durchflusszytometrie',
  'taktil',
  'Linux',
  'REM-Messungen',
  'Röntgen-Mikroskopie',
  'Laserscanningmikroskop',
  'Deconvolution',
  'Light microscopy',
  'Elektrophysiologie',
  'behaviour',
  'Fluorescence Microscopy',
  'MRI',
  'Grauwertkorrelation',
  'Synchrotron nanoCT',
  'Histologie',
  'Computertomographie (CT)',
  'Machine learning',
  'Luftbilder',
  'Niederschlagsverteilung',
  'PAM-Fluorometer',
  'UAV Daten',
  'Fotography',
  'aus Satellitendaten abgeleitete Daten',
  'Luftbilddaten',
  'Multispektrale Satellitendaten',
  'Image Processing',
  'Western Blot',
  'Optical Imaging ',
  'DEXA',
  'Ultraschall',
  'cryo-EM',
  'MEG',
  'Fotografie',
  'Mikroskopie von Geweben',
  'Fluorescence imaging',
  'Tiefenbilder ',
  'confocal microscopy',
  'Scintillator pulses'],
 'dataGenMethodSpec_1_3': ['AFM',
  'CT',
  'EBSD',
  'Farbanalyse',
  'Ultrafast imaging 2000 fps',
  'DXA',
  'Fluoreszenzmikroskopie',
  'Weißlichtchromatigrafie',
  'GISAXS',
  'Process cameras',
  'REM',
  'Tomography',
  'Photoakkustik',
  'Transmissionselektronenmikroskopie',
  'SEM',
  'Rasterkraftmethoden',
  'Tomography/ptychography',
  'X-ray Scanning Microscopy',
  'Home-built electron energy spectrometers',
  'Interferometrie',
  'histo-morphology',
  'Super-resolution Microscopy',
  'X-ray',
  'Ultraschall',
  'Neutron microCT',
  'XRD, SAXS',
  'Heliumionenmikroskopie',
  'NMR-System',
  'OpenStreetMap (Crowd-source)',
  'terrestrische Bilddaten',
  'Microscopy',
  'PET',
  'Bildverarbeitung von mir vorigen Methoden erfassten Daten',
  'Lichtmikroskopie',
  'eyetracking',
  'Mikroskopie von Drosophila (in vivo)',
  'Multispectral fluorescence',
  'US',
  'Live cell microscopy',
  '1P calcium imaging',
  'AFM-Messungen'],
 'dataGenMethodSpec_2_1': ['Spektroskopie',
  'HPLC',
  'Spectroscopy',
  'Next Generation Sequencing',
  'Mass spectrometry',
  'SAXS',
  'Röntgenabsorptionsspektroskopie',
  'ICP-MS/MS',
  'Photoelektronenspektroskopie',
  'Sequencing',
  'XRD',
  'XPS',
  'NEXAFS',
  'NMR',
  'Ferromagnetische Resonanz',
  'Small Angle Neutron Scattering ',
  'PIV ',
  'small angel scattering',
  'Beschleunigerspektometrie',
  'Neutronen Spektroskopie',
  'qPCR',
  'Photonenstrueung',
  'calorimeters ',
  'Likelihood methods applying spatial, temporal, and spectral models',
  'Photoelektronen-Spektroskopie (PES)',
  'pump-probe',
  'optical pump-probe spectroscopy',
  'Ion Beam Analysis',
  'Nanoindentation',
  'individual measurements',
  'Fluoreszenzspektroskopie',
  'Indentation',
  'Brillouin Lichtstreuung',
  'Reflektometrie',
  'Aufnahme von List-Mode-Daten',
  'Resonant inelastic X-ray spectroscoy',
  'neutron scattering spectroscopy',
  'Energiedispersive Röntgenspektroskopie',
  'Particle Detectors',
  'SEM',
  'MLA-Messung',
  'Genomics tools',
  'Gas chromatography',
  'Erzwungene Streumethoden',
  'Teilchenspur-Rekonstruktion',
  'Immunoblotting',
  'Röntgendiffraktion',
  'Wärmekapazität',
  'Röntgenspektroskopie',
  'Particle interactions in sensors',
  'XPCS',
  'Accelerator Mass Spectrometry',
  'Quasielastic Neutron Scattering',
  'Photoelectron spectroscopy',
  'XAS',
  'scattereing and diffraction',
  'Pump-probe experiments',
  'Ion and electron time of flight (TOF)',
  'spectroscopy',
  'x-ray diffraction',
  'XES',
  'Next generation sequencing',
  'SIMS',
  'Chemische Analysen von Blutproben',
  'scATAC-seq',
  'gene expression',
  'RNA Sequencing',
  'UV/vis/IR Spektroskopie',
  'Enzymatic Assays (determine enzyme activity or sugar concentration)',
  'Lidar',
  'ICP-MS',
  'NIRS',
  'Colorimetric methods (ELISA, MTT)',
  'HF radar',
  'Spektralanalyse Dopplerspektrum',
  'Preprocessing Remote sensing data',
  'UV/VIS-Spektroskopie',
  'MS',
  'Spektoskopie',
  'Optimal estimation',
  'Röntgenfluoreszenz',
  'IR Spektroskopie',
  'Analytical code',
  'From analytical model trace is generated',
  'GC/MS ',
  'numerous',
  'Mass Spectrometry',
  'UV-Vis Spektrophotometrie',
  'FPLC',
  'Flow cytometry',
  'Aggregation',
  'High Resolution Mass Spectrometry',
  'optische Messungen: Absorption, Fluoreszenz, Lumineszenz',
  'Single-cell sequencing',
  'Säulenchromatographie',
  'Software repository mining',
  'ELISA',
  'single-cell RNA-sequencing',
  'Plate reader',
  'Immunoassays',
  'FACS',
  'Optical absorbance spectroscopy',
  'Genomic sequencing',
  'Illumina EPIC DNA Methylation Array',
  'Hochdurchsatz-Screening: Auslesen von Lumineszenz',
  'Genotyping',
  'mass spectrometry',
  'Massenspektrometrie',
  'NGS Sequencing',
  'PCR',
  'Affinitätschromatographie',
  'RNA/DNA sequencing',
  'Molekularbiologische Analysen',
  'sequence data',
  'High-throughput sequencing',
  'DNA sequencing ',
  'DNA sequencing',
  'Massenspktrometrie',
  'Photometrie ',
  'Elektronen-Spektroskopie'],
 'dataGenMethodSpec_2_2': ['RIXS',
  'Chromatographie',
  'NEXAFS',
  'spectroscopy',
  'Massenspektrometrie',
  'Sequencing',
  'Mathematische Modelle',
  'reflectometry',
  'Massenspektrometie',
  'Physikalische Eigenschaften',
  'Resonante Beugung',
  'Neutron Spin Echo Spectroscopy',
  'Röntgenabsorbtionsspektroskopie (XAS)',
  'bulk measurements: magnetization',
  'Beugungssimulation',
  'Absorptionsspektrokopie',
  'Own python codes (cross corolation)',
  'Aufnahme von Signalformen',
  'Reciprocal Space Mapping',
  'SQUID/VSM',
  'time-domain THz spectroscopy',
  'Machine learning methods for signal/background separation',
  'spectrometers',
  'viability assays',
  'GISAXS',
  'X-ray absorption spectroscopy',
  'Massenspektroskopie',
  'MS',
  'chemische Analysen (XRF',
  'Scanning elctron microscopy',
  'Isotherme Titrationskalorimetrie',
  'machinelles Lernen',
  'Immunopräzipitation',
  'Magnetokalorischer Effekt',
  'Teilchenverfolgung',
  'ARPES',
  'Diffraction',
  'Mass spectrometry',
  'Home-built optical spectrometers',
  'Velocity map imaging (VMI)',
  'x-ray photoelecectron spectroscopy',
  'XAS',
  'PFG NMR',
  'SAM',
  'SANS',
  'RF measurements',
  'Bendingtest',
  'genotyping',
  'Size exclussion chromatography',
  'Whole genome sequencing',
  'single cell sequencing ',
  'Non-linear fitting',
  'Low Resolution Mass Spectrometry',
  'MC ICP MS',
  'Gravimetry (cell dry weight determination)',
  'Titration',
  'TD-NMR',
  'Atomic Absorption Spectrscopy',
  'satellite spectroscopy',
  'Feinwaagen',
  'Cyclic voltammetry',
  'Polarimetrie',
  'Elementanalytik',
  'Röntgenreflekotmetrie',
  'Strömungspotential-Messungen',
  'HPLC',
  'Flow Cytometry',
  'Diffraktometrie',
  'Isothermale Titrationskalorimetrie',
  'SDS-PAGE',
  'Durchflusszytometrie',
  'Zellstudien',
  'Plasmonresonanzspektroskopie',
  'NGS',
  'RNA-seq ',
  'Mass Spectrometry',
  'RNAseq',
  'cell sorting',
  'Proteomics',
  'qPCR',
  'Fluoresence spectroscopy',
  'GC',
  'RNA- und DNA-Sequenzierung',
  'cytometry',
  'Methylation Array',
  'Western Blotting',
  'Größenausschlusschromatographie',
  'Mass spectrometry proteomics',
  'Sequenzierung',
  'NMR',
  'adaptative immune receptor repertoire data',
  'Cytometry',
  'Röntgen-Spektroskopie'],
 'dataGenMethodSpec_2_3': ['Reflektometrie',
  'Voting',
  'XAS',
  'VSM',
  'various optical and electrical measurements',
  'Neutron Backscattering',
  'Röntgen und Neutronen-Diffraktion',
  'neutron spectroscopy',
  'GIWAXS',
  'Image proccessing using sci py skiimage ',
  'X-ray photoemission spectroscopy',
  'FIB',
  'small angle X-ray scattering',
  'Immunoblotting',
  'COLTRIMS / REMI',
  'Home-built electron energy spectrometers',
  'XPS',
  'Time resolved by pump--probe delay (electron and mass spectroscopies)',
  'NEXAFS',
  'time resolved XPS',
  'Simulation der Daten',
  'Neutronenstreuung',
  'Überlebenskurven',
  'Standard molecular & cell biology tools',
  'XRD/XRR',
  'FTIR spectroscopy and Raman',
  'Machine learning methods for regression',
  'counters',
  'NMR',
  'LSC',
  'Permeationsmessungen',
  'Massenspektrometrie',
  'Chronopotntiometry',
  'RNAseq',
  'chromatography ',
  'Radiative Transfer Models',
  'PCR-Methoden',
  'UV-vis Spektroskopie',
  'Bioinformatik',
  'HPLC-MS',
  'RNA Sequencing',
  'Molekularbiologische Methoden wie Western Blot, qPCR',
  'Krankenhausinformationssysteme',
  'TLC',
  'Excitation spectroscopy',
  'Deep sequencing',
  'Sequencing ',
  'HPLC',
  'proteomics, mass-spectroscopy',
  'XRD'],
 'dataGenMethodSpec_3_1': ['numerische Modelle',
  'Finite Element Analysis',
  'Molecular Dynamics',
  'Monte Carlo',
  'HPC',
  'CFD',
  'Numeric models',
  'density functional theory',
  'Mont Carlo Simulationen',
  'Tracking Rechnungen',
  'Tight binding model',
  'Density Functional Theory',
  'quantenchemische Rechnungen - ORCA',
  'Particle-in-Cell',
  'ODE',
  'Ray tracing',
  'Analytic Models with Numeric Solutions',
  'SESSA',
  'Multi-Agenten-Simulationen',
  'Density functional theory',
  'Numerical analysis',
  'Monte Carlo Simulationen',
  'Output from numerical simulations',
  'simulation and fitting of measured data',
  'numerische Integration',
  'Mikromagnetische Simulationen',
  'Mikromagnetische Simulationen (Mumax3)',
  'Monte-Carlo',
  'Matlab',
  'Particle-In-Cell (PIC)',
  'Quantenmolekulardynamik',
  'Markov Chain Monte Carlo',
  'FLUKA',
  'Wavepropagation',
  'DFT (ORCA)',
  'Physics generators (PYTHIA, HIJING, etc): event-by-event computer intensive computation on HPC',
  'Ray-Tracing',
  'Strahldynamik',
  'Independent programming',
  'Manually',
  'Programm zur Verfügung gestellt von E.F.',
  'Numerical models (solution of PDAE systems)',
  'Numerisch',
  'laufzeitmessungen',
  'FEL Simulationen',
  'Monte Carlo Teilchensimulationen (z.B. PYTHIA)',
  'State-of-the-art event generators',
  'Python Models',
  'Monte Carlo Modelle',
  'Boris computational spintronics',
  'GEANT4-based simulations of particle interactions',
  'Particle collisions',
  'Monte Carlo Simulations',
  'MC simulation',
  'ASTRA simulations',
  'Electron or ion trajectories for design/evaluation of electrostatic spectrometers',
  'Numeric model',
  'Self-developed Python code',
  'quantum chemical calculations',
  'transport models',
  'MC Event Generators for instrument development',
  'Pytorch models',
  'Polymer modeling',
  'Monte Carlo simulation',
  'Klimasimulation',
  'Verwendung von Wettermodellen',
  'RTM',
  'Wasserverteilung in Geländemodellen',
  'Speciation calculations',
  'qutip',
  'Flight simulation software',
  'Simulations on R',
  'Theoretische Modelle',
  'Optimierung',
  'Finite-Elemente Methoden',
  'Simulating a system with relevant effects is then used to generate the trace',
  'Metagenomic read simulation',
  'Deep Learning Modelle',
  'limited',
  'FE modelling',
  'FEm-Simulation (Mechanik/Fluidik)',
  'Single Particle Analysis',
  'Erzeugen von Objekten mit einer Wahrscheinlichkeitsverteilung auf möglichen Parametern',
  'Deep Learning',
  'simulation for transport mobility',
  'BlenderProc',
  'Monta-Carlo Simulationen',
  'Physical models',
  'Modeling',
  'Geoinformationsverarbeitumg',
  'Reanalysis data',
  'chemistry transport models',
  'eigene Skripte',
  'Regressionsmodelle',
  'custom Python scripts',
  'Polygenic risk scores',
  'Commercial electromagnetic solvers',
  'Land use regression model',
  'AlphaFold',
  'TOPAS ',
  'Chemical transport modellling',
  'Monte-Carlo Verfahren',
  'Heliosat Method for solar irradiance forecast',
  'Numerical models',
  'maschinelle Lernverfahren',
  'Modellrechnungen',
  'Renderverfahren',
  'Regionale Klimamodelle',
  'numersches Modell',
  'modelling',
  'Automatisierte Planungsunterstützung für Abwassernetzwerke',
  'Hydrologische Modelle',
  'Reanalyse',
  'Szenario-Berechungen',
  'Risikomodelle',
  '(thermo)mechanische numerische Modelle'],
 'dataGenMethodSpec_3_2': ['Computational Fluid Dynamics',
  'Evolutionäre Algorithmen',
  'Monte Carlo',
  'Molecular dynamics',
  'Finite element method',
  'Spin dynamics',
  'Ray Tracing Neutron Instrumentation',
  'Brownian Dynamics',
  'Postprocessing of the results of the numerical simulations',
  'Numerische Lösungen',
  'Raytracing',
  'CST',
  'Quantum chemistry',
  'Fitting/comparing analytic curve models to pump--probe scan data',
  'thermodynamische Berechnungen ',
  'HTC',
  'Geneis 1.3 simulations',
  'Monte Carlo simulations',
  'MOnte Carlo methods',
  'Fast simulation employing simplified models',
  'Specific numerical model calculations',
  'nsight compute',
  'physikalisch/theoretisch',
  'neue Analyse der Daten von F.S.',
  'Collection from 3rd Party resources',
  'EM-Felder',
  'Comsol',
  'Magnetohydrodynamics (MHD)',
  'Analytische Berechnungen',
  'Toy MC for evaluation of statistical uncertainties for time series and spectral analysis',
  'Atomic model building',
  'Optische Simulation',
  'Machine learning models',
  'Monte-Carlo Simulationen',
  'HPC',
  'Numerische Modelle',
  'c3 (PGI-FZJ)',
  'Sichtbarkeit/Abschattung in Geländemodellen',
  'Lagrangesche Transportmodelle',
  'Statistische Modelle',
  'Statistische Modellierungen ',
  'NWP model data',
  'Wettermodelle',
  'Klimamodelle',
  'weitere Statistische Modelle',
  'statistisch-analytische Methoden',
  'Globale Erdsystem-Modelle (ESM)',
  'statistische Modelle',
  'Strahlungstransportmodelle',
  'Fluka',
  'Phoenix',
  'Other regression-based hybrid model',
  'Custom deep learning models',
  'machine learning'],
 'dataGenMethodSpec_3_3': ['Fluid-Structure Interaction',
  'Game Engines',
  'NextNano',
  'ASTRA',
  'Plots of the final results',
  'Monte Carlo',
  'Molecular Dynamics Simulations',
  'Mesoscopic simulation',
  'Rosetta',
  'density functional theory',
  'Climate model data',
  'Empirische Modelle',
  'Machine Learning und Klimadaten',
  'Temperaturverläufe Tag/Monat/Jahr',
  'juqcs (JSC-FZJ)',
  'MD and QM simulations',
  'Automatic straction with no validation'],
 'dataGenMethodSpec_4_1': ['PLD',
  'Sputterdeposition',
  'thin film deposition',
  'Nasschemische Mikrowellensynthese',
  'Excel',
  'Probenpräparation durch Magnetronsputtering',
  'SLE',
  'Spray',
  'Mixing / Cleaning Chemicals',
  '3D-printing',
  'Oberflächenmodifikation mit Ionenstrahlen',
  'Radiomarkierung',
  'PVD',
  'Organische Chemie',
  'Illumina sequencing',
  'Library preparation',
  'Cloning',
  'Radiochemie',
  'Synthese von Peptiden',
  'Extraction',
  'Probenahme'],
 'dataGenMethodSpec_4_2': ['organische Chemie',
  'DNA sequencing',
  'PCR',
  'Anorganische Chemie',
  'Dünnschichtabscheidung',
  'PLD',
  'Lipid extraction',
  'Spattering',
  'CAD/CAM',
  'Probenpräparation durch Electrospray Ionisation',
  'Sputtering',
  'wet chemistry',
  'Probenteilung'],
 'dataGenMethodSpec_4_3': ['Peptidsynthese',
  'qPCR',
  'Colloid preparation',
  'Zerkleinern, Fest-Flüssig-Trennung, Trocknen'],
 'dataGenMethodSpec_5_1': ['Umfrage zu erfahrenen Szenarios einer Studie (Likert Skala)',
  'Interviews and questionnaires',
  'digital long-term surveys',
  'Interview',
  'Cohort analysis',
  'statistical testing',
  'Sortierung durch statische, nicht-lernende Algorithmen (z.B. string matching mit regexp)',
  'Statistical techniques for association analysis',
  'statistische Analyse von Messwerten',
  'Questionnaires',
  'User experience surveys',
  'Clinician Ratings',
  'LimeSurvey',
  'Standardized interviews',
  'Weibull statistics',
  'Erhebung mit Applikation',
  'Fragebögen, Scores',
  'Befragung im Interview, selbstauszufüllende Fragebögen',
  'Surveys',
  'field-based monitoring',
  'Umfragen',
  'standardisierte Fragebögen',
  'Survey',
  'Interviews (Audio, schriftliche Notizen)',
  'Food Frequency Questionnaire',
  'Online survey',
  'script-based postprocessing ',
  'Statistical analyses',
  'regression analysis',
  'Manual measurements/observations in the field',
  'Multivariate cluster analysis',
  'Statistische Verfahren',
  'Leitfrageninterview',
  'Befragungen (Online-Umfragen, Fragebogenstudien, Interviews)',
  'face-to-face interviews'],
 'dataGenMethodSpec_5_2': ['Interviews',
  'Fragebögen (Online-Umfrage-tools wie Lime-Survey, Papierfragebögen, E-Mail-Fragebögen)',
  'Laboratory studies in Virtual Reality',
  'environemntal data from GIS, shared field-based environmental data',
  'manipulation of netCDF and grib data',
  'Interviews with target consumers',
  'Fragebögen',
  'Verhaltensexperimente',
  'Messungen am TeilnehmerIn, Messstationen',
  'Tests',
  'Selbstausfüller',
  'survival analysis',
  'Manuelles Annotieren von Freitextdaten nach Ontologien, um diese maschinenlesbar zu machen',
  'Examinations',
  'Patient/Caregiver Questionnairs',
  'web-based questionnaires'],
 'dataGenMethodSpec_5_3': ['Voting',
  'Videoaufzeichnungen',
  'Neurophysical measurements',
  'Beobachtungen',
  'Beauftragen von Drfittinstituten',
  'Probandenuntersuchungen',
  'Laboratory measurements',
  'Neuropsychology',
  'calculation of usual dietary intakes (NIH SAS algorithms considering intra-individual variation)'],
 'dataGenMethodSpec_6_1': ['EKG',
  'Neuropsychologische Tests',
  'in vivo recordings (for example with silicon probes)',
  'A/D-Wandlung',
  'Statische und dynamische Lichtstreuung ',
  'individual or large area scans',
  'Strahlmessungen wie Größe, Länge ect',
  'small angle neutron scattering',
  'neutronenstreruung',
  'NSE',
  'small-angle scattering',
  'Aufnahme von Messreihen',
  'single crystal',
  'Electron positron collision',
  'Magnetic Field Measurement 2D and 3D',
  'Experiment raw data are calibrated and reconstructed on the GRID (WLCG)',
  'inflammatory biomarkers in serum samples',
  'Leistungsaufnahme',
  'Strahlparameter, Strahltransport',
  'Typische DAQ-Systeme (NIM, Digitizer, etc.)',
  'Sequenzierung & bioinformatische Auswertung',
  'Algorithmically',
  'Stationsdaten',
  'Tomo-Seq',
  'Fangnetze',
  'Statistische Analysen',
  'Geophysikalische Messungen',
  'Sensors',
  'Radarmessungen',
  'FerryBox',
  'LIDAR',
  'in vivo Screening von Drosophila (Auszählen / Beobachten von Drosophila)',
  'scattered light measurement (measure for biomass development)',
  'standardisierte Zählmethoden (Biodiversitätserhebungen)',
  'kombinierte Flugfallen (Insekten; jährlich)',
  'Ich gehe raus',
  'sateliite aquisitions',
  'Landnutzungsmodelle ',
  'Western Blot',
  'Sensoren, Thermokameras, Maschinenprotokolle'],
 'dataGenMethodSpec_6_2': ['Klinische Tests',
  'GIS',
  'Vermessung von Hohlraumresonatoren',
  'Temperatur, Druck im Prozessraum',
  'microbiome data from fecal samples',
  'Analysis level data are produced by user code running on the GRID and extracting smaller samples for end analysis',
  'Simulation',
  'powder',
  'total scattering',
  'SANS',
  'roentgenstreiing',
  'quasielastic neutron scattering',
  'elastic or inelastic measurements',
  'Evaneszente Lichtstreuung',
  'Schnittstellen (Busse, Geräte)',
  'Histopathologie',
  'patch clamp and field recording in vitro',
  'qPCR',
  'CRISPR Screening (Sequenzierung und Datenauswertung)',
  'RNA-Sequencing',
  'Blutdruck',
  'airial photography',
  'Ich schaue',
  'Vogelerfassung (Punkt-Stopp-methode; alle 3 Jahre)',
  'passive Fallen (Biodiversitätserhebungen)',
  'pH and dissolved oxygen measurement via optodes',
  'IR Interferometrie',
  'Smartphone Daten',
  'Under water nodes',
  'Zugversuche, Stauchversuche'],
 'dataGenMethodSpec_6_3': ['Experimente',
  'Ich schreibe auf (OK, es gibt eine Reihe von Standards und Methoden, für die der Platz nicht reicht)',
  'Mikroneurographie',
  'PCR',
  'Bioinformatische Datenanalyse von Hochdurchsatz-Experimenten',
  'Zellkultur',
  'Verhaltens- und Neurologische Tests',
  'rheologie',
  'diffraction',
  'PDF',
  'Machine learning and neural network techniques on local farm (or laptop, sometimes)',
  'metabolic markers in blood (glucose metabolism, lipoproteins and triglycerides)',
  'Massestrom',
  'Härteprüfungen'],
 'dataGenMethodSpec_7_1': [],
 'dataGenMethodSpec_7_2': [],
 'dataGenMethodSpec_7_3': [],
 'dataFormats_1': [True],
 'dataFormats_2': [True],
 'dataFormats_3': [True],
 'dataFormats_4': [True],
 'dataFormats_5': [True],
 'dataFormats_6': [True],
 'dataFormats_7': [True],
 'dataFormats_8': [True],
 'dataFormats_9': [True],
 'dataFormats_10': [True],
 'dataFormats_11': [True],
 'dataFormats_12': [True],
 'dataFormats_13': [True],
 'dataFormats_14': [True],
 'dataFormats_15': [True],
 'dataFormats_other': ['Other',
  'Binary non-scientific formats',
  'Binary scientific formats',
  'Plain text',
  'Structured text',
  'Application-specific formats',
  'Image formats'],
 'servNeeds_sub_1': [True],
 'servNeeds_sub_2': [True],
 'servNeeds_sub_3': [True],
 'servNeeds_sub_4': [True],
 'servNeeds_sub_5': [True],
 'servNeeds_sub_6': [True],
 'servNeeds_sub_7': [True],
 'servNeeds_sub_8': [True],
 'servNeeds_sub_9': [True],
 'servNeeds_sub_other': ['RDM software & tools',
  'Technical aspects of RDM',
  'Best practices',
  'Financial resources for RDM',
  'Metadata enrichment of research data'],
 'servNeeds_sub_0': [True],
 'servFormat_1': ['moderately interested',
  'very interested',
  'not interested'],
 'servFormat_2': ['very interested',
  'moderately interested',
  'not interested'],
 'servFormat_3': ['moderately interested',
  'very interested',
  'not interested'],
 'servFormat_4': ['moderately interested',
  'not interested',
  'very interested'],
 'servFormat_5': ['very interested',
  'moderately interested',
  'not interested'],
 'servFormat_6': ['moderately interested',
  'very interested',
  'not interested']
}


# This what will be displayed in selection widgets and titles
HCSquestions_long = {
                "EN" : {        
                        "PERBG1/_":"Which Helmholtz center do you typically work in?",
                        "PERBG2/_":"Please select the Helmholtz research field you associate yourself with.",
                        "PERBG3/_":"Please select your principle research area.",
                        "PERBG4/_":"How many years have you been working in research?",
                        "PERBG6/_":"Which is your current career level?",
                        "PERBG7/_":"Do you have an ORCID iD?",
                        "PERBG8/_":"How familiar are you with the FAIR data guidelines?",
                        "RSDP1":"Please characterize the origin of your research data.",
                        "RSDP1b/1":"Which amount of your data sets was recorded at large scale facilities (e.g., LHC, PETRA III, KATRIN, ELBE, BESSY II)? (Percentage)",
                        "RSDP1c":"Please specify the large scale facility used:",
                        "RSDP2":"Please select the methods used to generate your research data.",
                        "RSDP2b":"Please specify the methods used to generate your research data.",
                        "RSDP3":"Please select the data formats that you generate or use in your current research project.",
                        "RSDP7/_":"Please estimate the amount of data a typical publication of yours is based on.",
                        "RSDP4/_":"What is the average time from planning to completion of data collection for your research projects? (in months)",
                        "RSDP8/_":"My experiments take ___ time than an average investigation in my research domain.",
                        "RSDP11/_":"My data analyses take ___ time than an average investigation in my research domain.",
                        "RSDP10/_":"Do you keep your unpublished raw data in long-term storage (10 years or longer)?",
                        "DTPUB6/1":"Please estimate the relative amount of your data sets that you make publicly available. (Percentage)",
                        "DTPUB1b":"How did you publish your data?",
                        "DTPUB5":"In which repositories have you published your data?",
                        "DTPUB3":"Which of the following motivated you to publish your data? (Please choose up to 3 options)",
                        "DTPUB4a":"What obstacles have you encountered in publishing your research data?",
                        "DTPUB4b":"What concerns or obstacles have discouraged you from publishing your research data so far?",
                        "RDMPR1":"Where is most of your research data stored after a project is finished?",
                        "RDMPR3":"In your current project, where do you document the steps used to generate and process your data?",
                        "RDMPR7":"Please select which information (metadata) you typically use to describe your research data?",
                        "RDMPR8":"Which information (metadata) do you typically document in a digital way?",
                        "RDMPR9":"Which of those information (metadata) do you typically gather in an automated way?",
                        "RDMPR4/_":"Do you document your research data in a structured way? (e.g., using forms, templates or schemas)",
                        "RDMPR5/_":"Do you use internationally used templates, schemas or standards for this purpose?",
                        "DTPUB7":"Which of these metadata do you publish along with your research data?",
                        "RDMPR6":"Which international standards do you use?",
                        "RDMPR10":"Please name the three most important software applications that you use for your research.",
                        "RDMPR12":"Which of these reasons motivates you to document your work in a structured way?",
                        "RDMPR11":"What obstacles or difficulties have you encountered in collecting metadata as part of your work?",
                        "SERVC1":"In which areas of research data management do you perceive a need for supporting services?",
                        "SERVC2":"Please rate your interest in the following service formats.",
                        "SERVC3":"You are almost there! You are welcome to formulate questions, wishes or suggestions in the following free text field:"
                        },
                "DE" : {
                        "PERBG1/_":"In welchem Helmholtz-Zentrum sind Sie in erster Linie tätig?",
                        "PERBG2/_":"Welchem Helmholtz-Forschungsbereich ordnen Sie sich am ehesten zu?",
                        "PERBG3/_":"Welcher Forschungsdisziplin ordnen Sie sich am ehesten zu?",
                        "PERBG4/_":"Wie viele Jahre sind Sie bereits in der Forschung tätig?",
                        "PERBG6/_":"Was ist Ihre aktuelle Position?",
                        "PERBG7/_":"Haben Sie eine ORCID iD?",
                        "PERBG8/_":"Wie vertraut sind Sie mit den FAIR-Data Leitlinien?",
                        "RSDP1":"Bitte charakterisieren Sie den Ursprung Ihrer Forschungsdaten.",
                        "RSDP1b/1":"Welcher Anteil Ihrer Datensätze wurde an Großforschungsanlagen (z.B. LHC, PETRA III, KATRIN ELBE, BESSY II) erfasst? (Angabe in Prozent)",
                        "RSDP1c":"Bitte nennen Sie die genutzte Großforschungseinrichtung:",
                        "RSDP2":"Mit welchen Methoden erheben Sie Ihre Forschungsdaten?",
                        "RSDP2b":"Bitte spezifizieren Sie die Methoden, mit denen Sie Ihre Forschungsdaten erheben.",
                        "RSDP3":"In welchen Datenformaten liegen die Daten vor, die Sie in Ihrem aktuellen Forschungsprojekt generieren bzw. nutzen?",
                        "RSDP7/_":"Bitte schätzen Sie, auf welcher Datenmenge eine typische Veröffentlichung von Ihnen beruht.",
                        "RSDP4/_":"Wie viel Zeit vergeht durchschnittlich von der Planung bis zum Abschluss der Datenaufnahme für Ihre Forschungsprojekte? (in Monaten)",
                        "RSDP8/_":"Meine Experimente nehmen ___ Zeit in Anspruch als eine durchnittliche Untersuchung in meinem Forschungsbereich.",
                        "RSDP11/_":"Meine Datenanalysen nehmen ___ Zeit in Anspruch als eine durchschnittliche Untersuchung in meinem Forschungsbereich.",
                        "RSDP10/_":"Speichern Sie Rohdaten, die nicht publiziert werden, langfristig (10 Jahre und länger)?",
                        "DTPUB6/1":"Bitte schätzen Sie, welchen relativen Anteil Ihrer Datensätze Sie publizieren. (Angabe in Prozent)",
                        "DTPUB1b":"Wie haben Sie Ihre Daten publiziert?",
                        "DTPUB5":"In welchen Repositorien haben Sie Ihre Daten veröffentlicht?",
                        "DTPUB3":"Was motivierte Sie dazu, Ihre Forschungsdaten zu veröffentlichen? (Bitte wählen Sie bis zu 3 Antworten)",
                        "DTPUB4a":"Auf welche Hindernisse sind Sie bei der Veröffentlichung Ihrer Forschungsdaten gestoßen?",
                        "DTPUB4b":"Welche Bedenken oder Hindernisse haben Sie bisher davon abgehalten, Ihre Forschungsdaten zu veröffentlichen?",
                        "RDMPR1":"Wo werden Ihre Forschungsdaten nach Abschluss eine Projekts hauptsächlich gespeichert?",
                        "RDMPR3":"Wo dokumentieren Sie in Ihrem aktuellen Projekt die Arbeitsschritte, mit denen Ihre Daten erzeugt und verarbeitet werden?",
                        "RDMPR7":"Mit welchen Informationen (Metadaten) beschreiben Sie normalerweise Ihre Forschungsdaten?",
                        "RDMPR8/_":"Welche Informationen (Metadaten) davon erfassen Sie in der Regel digital?",
                        "RDMPR9":"Welche dieser Informationen (Metadaten) erfassen Sie in der Regel automatisiert?",
                        "RDMPR4/_":"Dokumentieren Sie Ihre Forschungsdaten auf strukturierte Weise? (z.B. mittels Formularen, Vorlagen oder Schemata)",
                        "RDMPR5/_":"Verwenden Sie hierzu international genutzte Formulare, Schemata oder Standards?",
                        "DTPUB7":"Welche dieser Metadaten publizieren Sie zusammen mit Ihren Forschungsdaten?",
                        "RDMPR6":"Welche internationalen Standards nutzen Sie?",
                        "RDMPR10":"Bitte nennen Sie die drei wichtigsten Softwareanwendungen, die Sie für Ihre Forschung verwenden.",
                        "RDMPR12":"Was motiviert Sie dazu, Ihre Arbeitsschritte auf strukturierte Weise zu dokumentieren?",
                        "RDMPR11":"Auf welche Hindernisse oder Schwierigkeiten sind Sie bei der Erfassung von Metadaten im Rahmen Ihrer Arbeit gestoßen?",
                        "SERVC1":"In welchen Bereichen des Forschungsdatenmanagements haben Sie Bedarf an unterstützenden Angeboten?",
                        "SERVC2":"Bitte bewerten Sie Ihr Interesse an den folgenden Service-Formaten.",
                        "SERVC3":"Sie haben es fast geschafft! Gerne können Sie Fragen, Wünsche oder Anregungen im folgenden Freitextfeld formulieren:"
                        }
                    }
# These are used as displays on selection and for titles
HCSquestions = { # shortened
                "EN" : {        
                        "PERBG1/_":"Helmholtz center participants typically work in",
                        "PERBG2/_":"Helmholtz research field participants associate with.",
                        "PERBG3/_":"Principle research area of participants.",
                        "PERBG4/_":"Working years in research.",
                        "PERBG6/_":"Career level of participants.",
                        "PERBG7/_":"Do you have an ORCID ID?",
                        "PERBG8/_":"Familiarity with the FAIR data guidelines",
                        "RSDP1":"Origin of research data.",
                        "RSDP1b/1":"Percentage of data sets recorded at large scale facilities.",
                        "RSDP1c":"Large scale facilities used.",
                        "RSDP2":"Research data generation methods used (selected).",
                        "RSDP2b":"Research data generation methods used (specified).",
                        "RSDP3":"Data formats used in research projects.",
                        "RSDP7/_":"Amount of data a typical publication is based on.",
                        "RSDP4/_":"Average time from planning to completion for projects. (months)",
                        "RSDP8/_":"Experiments take ___ time than on average in my domain.",
                        "RSDP11/_":"Data analyses take ___ time than on average in my domain.",
                        "RSDP10/_":"Unpublished raw data kept in long-term storage (>10 years).",
                        "DTPUB6/1":"Percentage of data sets made publicly available.",
                        "DTPUB1b":"How data was publised.",
                        "DTPUB5":"Repositories data is published in.",
                        "DTPUB3":"Motivations to publish data.",
                        "DTPUB4a":"Obstacles for publishing research data.",
                        "DTPUB4b":"Discouragements for publishing data so far.",
                        "RDMPR1":"Data storage for finished projects.",
                        "RDMPR3":"Where are data generation and processing are documented.",
                        "RDMPR7":"Information (metadata) typically used to describe research data.",
                        "RDMPR8":"Information (metadata) typically documented in digital way.",
                        "RDMPR9":"Information (metadata) typically gathered in automated way.",
                        "RDMPR4/_":"Reseach data documented in a structured way.",
                        "RDMPR5/_":"Usage of internationally templates, schemas or standards.",
                        "DTPUB7":"Metadata published along with research data.",
                        "RDMPR6":"International standards in use.",
                        "RDMPR10":"Three most important software applications used in research.",
                        "RDMPR12":"Motivations to documented work in a structured way.",
                        "RDMPR11":"Difficulties in collecting metadata as part of work.",
                        "SERVC1":" Support or services needed by research data management area.",
                        "SERVC2":"Interest in certain service formats.",
                        "SERVC3":"Free feedback text field:"
                        },
                "DE" : {
                        "PERBG1/_":"Helmholtz-Zentrum der Teilnehmenden.",
                        "PERBG2/_":"Helmholtz-Forschungsbereich der Teilnehmenden.",
                        "PERBG3/_":"Forschungsdisziplin der Teilnehmenden.",
                        "PERBG4/_":"Dauer der Beschäftigung in der Forschung in Jahren.",
                        "PERBG6/_":"Aktuelle Position der Teilnehmenden.",
                        "PERBG7/_":"Haben Sie eine ORCID iD?",
                        "PERBG8/_":"Vertrautheit mit den FAIR-Data Leitlinien.",
                        "RSDP1":"Ursprung der Forschungsdaten.",
                        "RSDP1b/1":"Relativer Anteil der an Großforschungsanlagen erfassten Datensätze.",
                        "RSDP1c":"Genutzte Großforschungseinrichtungen.",
                        "RSDP2":"Ausgewählte Methoden der Forschungsdatenerhebung.",
                        "RSDP2b":"Spezifische Methoden der Forschungsdatenerhebung.",
                        "RSDP3":"Datenformate, generiert / verwendet in aktuellen Forschungsprojekten.",
                        "RSDP7/_":"Bitte schätzen Sie, auf welcher Datenmenge eine typische Veröffentlichung von Ihnen beruht.",
                        "RSDP4/_":"Durchschnittliche Dauer von Planung bis Abschluss der Datenaufnahme in Monaten.",
                        "RSDP8/_":"Meine Experimente nehmen ___ Zeit in Anspruch als der Durchschnitt in meinem Forschungsbereich.",
                        "RSDP11/_":"Meine Datenanalysen nehmen ___ Zeit in Anspruch als der Durchschnitt in meinem Forschungsbereich.",
                        "RSDP10/_":"Langfristige Speicherung unpublizierter Rohdaten (> 10 Jahre).",
                        "DTPUB6/1":"Gescgätzter relativer Anteil der publizierten Datensätze.",
                        "DTPUB1b":"Art der Datenpublikation.",
                        "DTPUB5":"Repositorien in denen Daten veröffentlicht wurden.",
                        "DTPUB3":"Motivation für die Forschungsdatenveröffentlichung.",
                        "DTPUB4a":"Hindernisse während der Forschungsdatenveröffentlichung.",
                        "DTPUB4b":"Bisherige Gründe, die gegen eine Forschungsdatenveröffentlichung sprechen.",
                        "RDMPR1":"Speicherort der Forschungsdaten nach Abschluss eine Projekts.",
                        "RDMPR3":"Dokumentationsmethode der Arbeitsschritte, mit denen Daten erzeugt und verarbeitet wurden.",
                        "RDMPR7":"Informationen (Metadaten) zur Beschreibung der Forschungsdaten.",
                        "RDMPR8/_":"Informationen (Metadaten), die digital erfasst werden.",
                        "RDMPR9":"Informationen (Metadaten), die automatisiert erfasst werden.",
                        "RDMPR4/_":"Strukturierte Dokumentation der Forschungsdaten.",
                        "RDMPR5/_":"Verwendung international genutzter Formulare, Schemata oder Standards?",
                        "DTPUB7":"Metadaten, die mit Forschungsdaten publiziert werden.",
                        "RDMPR6":"Genutzte internationale Standards.",
                        "RDMPR10":"Meistgenutzte Softwareanwendungen.",
                        "RDMPR12":"Motivation für strukturierte Dokumentation der Arbeitsschritte.",
                        "RDMPR11":"Hindernisse währund der Erfassung von Metadaten.",
                        "SERVC1":"Unterstütztungsbedarf in Bereichen des Forschungsdatenmanagements.",
                        "SERVC2":"Interesse an ausgewählten Service-Formaten.",
                        "SERVC3":"Sie haben es fast geschafft! Gerne können Sie Fragen, Wünsche oder Anregungen im folgenden Freitextfeld formulieren:"
                        }
                    }


# Dashboard specific white lists
# for now all bar charts
visualization_per_question = {}


BARCHART_ALLOWED = [
"researchFieldHGF",
"researchArea",
"yearsInResearch",
"careerLevel",
"orcid",
"fairFamiliarity",
"dataAmount_lsf",
"dataInPublication",
"dataGatherTime",
"experimentDuration_sub",
"dataAnalDuration_sub",
"longtermStorage",
"pubAmount",
"docStructured",
"docDefSchema",
"dataGenMethod_",
"lsfIdent_",
"dataFormats_",
"pubMethod_",
"pubMotivation_",
"pubObstaclesA_",
"pubObstaclesB_",
"pubMetadata_",
"docMethod_",
"docMetadata_",
"docMotivation_",
"docStandards_",
"docObstacles_",
"servNeeds_sub_"]

corr_chart_allowed = [
"researchFieldHGF",
"researchArea",
"yearsInResearch",
"careerLevel",
"orcid",
"fairFamiliarity",
"dataAmount_lsf",
"dataInPublication",
"dataGatherTime",
"experimentDuration_sub",
"dataAnalDuration_sub",
"longtermStorage",
"pubAmount",
"docStructured",
"docDefSchema"]

multi_chart_allowed = [
"dataGenMethod_",
"lsfIdent_",
"dataFormats_", 
"pubMethod_", 
"pubMotivation_", 
"pubObstacles_", 
"pubMetadata_", 
"pubStorage_", 
"docMethod_", 
"docMetadata_", 
"docMotivation_", 
"docStandards_", 
"docObstacles_",
"servNeeds_sub_"
]


FILTER_OPTIONS = {
    "method": [
        "imaging",
        "analytical methods",
        "simulations",
        "sample synthesis and preparation",
        "cohort studies",
        "recordings"],
    "researchArea" : [
        "All",
        #"Biology",
        "Cum. Sum",
        "Chemistry",
        #"Computer Science",
        "Earth Science",
        "Engineering Science",
        #"Health",
        "Life Science",
        "Mathematics",
        "Other",
        "Physics",
        "Psychology"],
    "HGFresearchField" : [
        "All",
        "Cum. Sum",
        "Chemistry",
        #"Computer Science",
        "Earth Science",
        "Engineering Science",
        "Life Science",
        "Mathematics",
        "Other",
        "Physics",
        "Psychology"],
    "LargeScaleFacility" : [
        "All",
        "Cum. Sum",
        "Chemistry",
        #"Computer Science",
        "Earth Science",
        "Engineering Science",
        "Life Science",
        "Mathematics",
        "Other",
        "Physics",
        "Psychology"],
    "CareerLevel" :
        ['Student', 
        'PhD candidate', 
        'Postdoc', 
        'Research Associate', 
        'Principal Investigator', 
        'Technical Staff', 
        'Other']
}



# -*- coding: utf-8 -*-
###############################################################################
# Copyright (c), Forschungszentrum Jülich GmbH, IAS-9, Germany.               #
#                All rights reserved.                                         #
# This file is part of the survey_dashboard package.                          #
#                                                                             #
# The code is hosted on GitHub at                                             #
# https://github.com/Materials-Data-Science-and-Informatics/survey_dashboard  #
# For further information on the license, see the LICENSE file                #
###############################################################################
"""
This module contains some function to process survey data in certain way and 
prepare the data for visualization
"""
import math
import pandas as pd
from typing import List, Tuple

def calculate_crosstab(df: pd.DataFrame, data_key1: str, data_key2: str, id_vars: str=None, astype: str="int") -> pd.DataFrame:
    """Calulate the cross table for two keys in a given pandas data frame"""

    if id_vars is None:
        id_vars = data_key1

    cols = [data_key1, data_key2]

    df0 = df[cols].dropna(how = "all", subset = cols).astype("category")
    totals = dict(df0[data_key1].value_counts())

    df_crosstab = pd.crosstab(df[data_key1], df[data_key2],
                              margins = False).reset_index().melt(id_vars = [id_vars])
    
    # include total answers by career level in cross tab
    df_crosstab["total"] = df_crosstab[data_key1].map(totals).astype(astype)
    
    # calculate relative amount of answers by career level
    df_crosstab["percentage"] = (df_crosstab["value"] / df_crosstab["total"]) * 100
    
    return df_crosstab


def filter_dataframe(df: pd.DataFrame, include: list=None, exclude: List[Tuple[str, list]]=None, 
                exclude_nan=True, exclude_anonymized=True, as_type="category") -> pd.DataFrame:
    """
    Filter a pandas dataframe

    example:
    ```
    to_exclude = ['Other', 'Undergraduate / Masters student', 'Director (of the institute)']
    df = filter_dataframe(surveydata, include=["careerLevel", "docStructured", "researchArea"], exclude=[("careerLevel", to_exclude)])

    returns a dataFrame with columns ["careerLevel", "docStructured", "researchArea"], 
    where rows which contain to_exclude values in the "careerLevel" column are removed
    ```
    """


    if include is not None:
        df = df[include].dropna(how = "all", subset = include).astype(as_type)
    
    for key, val in exclude:
        #print(key, val)
        df = df.loc[~df[key].isin(val)]
    
    if exclude_nan:
        for key in df.keys():
            df = df.loc[~df[key].isna()]

    if exclude_anonymized:
        df = df.replace(to_replace="Anonymized", value="") 

    return df

def get_all_values(df: pd.DataFrame, keylist: List[str], display_dict=None) -> dict:
    """
    Count all values of a given key from a key list in a data frame and 
    return these values in a dictionary sorted.

    """
    if len(keylist) == 1:
        key = keylist[0]
        all_areas = df[key].value_counts()
        all_areas = all_areas.sort_index()
        data = {'All': all_areas.values, key:list(all_areas.keys())}
    else: # multiple keys now the keys become the xticks
        combined = {}
        for key in keylist:
            if display_dict is not None:
                xtick = display_dict[key]
            else:
                xtick = key
            xtick = xtick.replace(' \n', '')
            temp = df[key]
            temp.replace(to_replace=True, value=xtick, inplace=True)
            temp.replace(to_replace=False, value=None, inplace=True)
            a = temp.value_counts()
            if a.empty:
                combined[xtick] = 0
            else:
                # greedy, there is probably a pandas way to do this...
                # there is a problem if df is empty, i.e temp.value_counts() True 0
                for i, ke in enumerate(a.keys()):
                    # because other can contain all... others..
                    #ke = ke.lower() # sometimes there are mixed upper and lower case keys...
                    #ke = ke.replace(' \n', '') # some are with and without breaks
                    temp_val = combined.get(ke, 0)
                    temp_val = temp_val + a.values[i]
                    combined[ke] = temp_val

            #for i, ke in enumerate(a.keys()):
            #    ke = ke.lower() # sometimes there are mixed upper and lower case keys...
            #    ke = ke.replace(' \n', '') # some are with and without breaks
            #    temp_val = combined.get(ke, 0)
            #    temp_val = temp_val + a.values[i]
            #    combined[ke] = temp_val
        data = {'All' : list(combined.values()), key:list(combined.keys())}
    return data


def prepare_data_research_field(df: pd.DataFrame, keylist:List[str], key2:str='researchArea', sort_as=None, display_dict= None):# -> dict, list:
    """Creates a dict dictionary with data in the form needed by the plotting functions
    
    We prepare several outputs, i.e y_keys because they can have different length and one should be able to create a 
    ColumnDataSource by ColumnDataSource(data=data)
    :param df: [description]
    :type df: pd.DataFrame
    :param key: [description]
    :type key: str

    example:
    prepare_data_research_field(df, key=careerLevel)
        {'Cum. Sum': array([  0,   0, 130, 128, 148, 272,   0]),
         'careerLevel': ['Director (of the institute)',
          'Other',
          'PhD student',
          'Postdoc',
          'Principal Investigator',
          'Research associate',
          'Undergraduate / Masters student'],
         'researchArea': ['Engineering Science',
          'Physics',
          'Life Science',
          'Earth Science',
          'Chemistry',
          'Other',
          'Psychology',
          'Mathematics'],
         'Engineering Science': array([  0,   0,  47,  30,  52, 134,   0]),
         'Physics': array([ 0,  0, 33, 38, 39, 57,  0]),
         'Life Science': array([ 0,  0, 28, 29, 27, 33,  0]),
         'Earth Science': array([ 0,  0,  8, 11, 18, 32,  0]),
         'Chemistry': array([ 0,  0,  9, 12,  6,  4,  0]),
         'Other': array([0, 0, 1, 2, 3, 6, 0]),
         'Psychology': array([0, 0, 3, 2, 3, 2, 0]),
         'Mathematics': array([0, 0, 1, 4, 0, 4, 0])}

    """
    research_areas = list(df[key2].value_counts().keys())
    y_keys = ['Cum. Sum'] + research_areas
    # Multiple columns will be combined. A single column will be treated differently
    if len(keylist) == 1:
        key = keylist[0]
        all_areas = df[key].value_counts()
        all_areas = all_areas.sort_index()
        data = {'Cum. Sum': all_areas.values, key:list(all_areas.keys()), 'x_value': list(all_areas.keys())}
        for area in research_areas:
            area_counts = df[df[key2] == area][key].value_counts()
            area_counts = area_counts.sort_index()
            data[area] = area_counts.values
    else:
        # Cum. Sum. is buggy?
        combined = {}
        data = {}
        for key in keylist:
            if display_dict is not None:
                xtick = display_dict[key]
            else:
                xtick = key
            xtick = xtick.replace(' \n', '')
            temp = df[key]
            temp.replace(to_replace=True, value=xtick, inplace=True)
            temp.replace(to_replace=False, value=None, inplace=True)
            a = temp.value_counts()
            # greedy, there is probably a pandas way to do this...
            # there is a problem if df is empty, i.e temp.value_counts() True 0
            if a.empty:
                combined[xtick] = 0
            else:  
                for i, ke in enumerate(a.keys()):
                    # because other can contain all... others..
                    #ke = ke.lower() # sometimes there are mixed upper and lower case keys...
                    #ke = ke.replace(' \n', '') # some are with and without breaks
                    temp_val = combined.get(ke, 0)
                    temp_val = temp_val + a.values[i]
                    combined[ke] = temp_val
            
            # now fill research area specifics
            for area in research_areas:
                area_counts = df[df[key2] == area][key]
                area_counts.replace(to_replace=True, value=xtick, inplace=True)
                area_counts.replace(to_replace=False, value=None, inplace=True)
                area_counts = area_counts.value_counts()
                area_counts = area_counts.sort_index()
                temp = data.get(area, [])
                #print(area_counts)
                if area_counts.empty:
                    temp.append(0)
                else:
                    temp.append(int(area_counts.values[0]))
                data[area] = temp
        
        data['Cum. Sum'] = list(combined.values())
        data['x_value'] = list(combined.keys())

    return data, y_keys

'''
def prepare_data_research_field(df: pd.DataFrame, key:str, key2:str='researchArea', sort_as=None):# -> dict, list:
    """Creates a dict dictionary with data in the form needed by the plotting functions
    
    We prepare several outputs, i.e y_keys because they can have different length and one should be able to create a 
    ColumnDataSource by ColumnDataSource(data=data)
    :param df: [description]
    :type df: pd.DataFrame
    :param key: [description]
    :type key: str

    example:
    prepare_data_research_field(df, key=careerLevel)
        {'Cum. Sum': array([  0,   0, 130, 128, 148, 272,   0]),
         'careerLevel': ['Director (of the institute)',
          'Other',
          'PhD student',
          'Postdoc',
          'Principal Investigator',
          'Research associate',
          'Undergraduate / Masters student'],
         'researchArea': ['Engineering Science',
          'Physics',
          'Life Science',
          'Earth Science',
          'Chemistry',
          'Other',
          'Psychology',
          'Mathematics'],
         'Engineering Science': array([  0,   0,  47,  30,  52, 134,   0]),
         'Physics': array([ 0,  0, 33, 38, 39, 57,  0]),
         'Life Science': array([ 0,  0, 28, 29, 27, 33,  0]),
         'Earth Science': array([ 0,  0,  8, 11, 18, 32,  0]),
         'Chemistry': array([ 0,  0,  9, 12,  6,  4,  0]),
         'Other': array([0, 0, 1, 2, 3, 6, 0]),
         'Psychology': array([0, 0, 3, 2, 3, 2, 0]),
         'Mathematics': array([0, 0, 1, 4, 0, 4, 0])}

    """
    all_areas = df[key].value_counts()
    all_areas = all_areas.sort_index()
    research_areas = list(df[key2].value_counts().keys())
    data = {'Cum. Sum': all_areas.values, key:list(all_areas.keys()), 'x_value': list(all_areas.keys())}
    y_keys = ['Cum. Sum'] + research_areas
    for area in research_areas:
        area_counts = df[df[key2] == area][key].value_counts()
        area_counts = area_counts.sort_index()
        data[area] = area_counts.values
    
    return data, y_keys
'''
'''
def prepare_data_research_field(df: pd.DataFrame, key:str):
    """AI is creating summary for prepare_data_researchfield

    :param df: [description]
    :type df: pd.DataFrame
    :param key: [description]
    :type key: str
    """
    all_areas = df[key].value_counts()
    all_areas = all_areas.sort_index()
    data = {'All': {'counts': all_areas.values, 'values': list(all_areas.keys())}}
    research_areas = list(df['researchArea'].value_counts().keys())
    for area in research_areas:
        area_counts = df[df["researchArea"] == area][key].value_counts()
        area_counts = area_counts.sort_index()
        data[area] = {'counts': area_counts.values, 'values': list(area_counts.keys())}
    
    return data
'''

def percentage_to_area(data: List[float], scale_m: float=1.0) -> List[float]:
    """
    Convert numbers in a given array to a radius, 
    
    where a circle of with that radius is proportionate to the circle area 
    Useful for circle plots where the area should be proportional to the value
    """
    radius_data = [2*math.sqrt(val*scale_m/math.pi) for val in data]
    return radius_data


# -*- coding: utf-8 -*-
###############################################################################
# Copyright (c), Forschungszentrum Jülich GmbH, IAS-9, Germany.               #
#                All rights reserved.                                         #
# This file is part of the survey_dashboard package.                          #
#                                                                             #
# The code is hosted on GitHub at                                             #
# https://github.com/Materials-Data-Science-and-Informatics/survey_dashboard  #
# For further information on the license, see the LICENSE file                #
###############################################################################
import requests
# HMC survey data:
#doi = 'https://doi.org/10.7802/2433'
#https://search.gesis.org/research_data/SDN-10.7802-2433?doi=10.7802/2433
#url="https://access.gesis.org/sharing/2433/3778"

def download_data(url="https://access.gesis.org/sharing/2433/3778", 
    destination="survey_dashboard/data/hmc_survey_2021_data_cleaned.csv"):
    """
    This function downloads the dataset for a given DOI
    """
    # For now go to the website of the DOI and download by hand

    with open(destination, "wb") as fileo:
        fileo.write(requests.get(url).content)




# -*- coding: utf-8 -*-
###############################################################################
# Copyright (c), Forschungszentrum Jülich GmbH, IAS-9, Germany.               #
#                All rights reserved.                                         #
# This file is part of the survey_dashboard package.                          #
#                                                                             #
# The code is hosted on GitHub at                                             #
# https://github.com/Materials-Data-Science-and-Informatics/survey_dashboard  #
# For further information on the license, see the LICENSE file                #
###############################################################################
"""
This file contains the main code for the dashboard and its layout.
"""
import os
from os.path import dirname, join
import pandas as pd
import panel as pn
from bokeh.palettes import Category20
from bokeh.models import ColumnDataSource, Div
from .plots import bokeh_barchart, bokeh_piechart, add_legend_at, bokeh_corr_plot
from .plots import create_legend_corr, generate_wordcloud, interactive_wordcloud
from .plots import DEFAULT_FIGURE_WIDTH, DEFAULT_FIGURE_HEIGHT
from .analysis import calculate_crosstab, prepare_data_research_field, filter_dataframe
from .analysis import percentage_to_area, get_all_values
from .data.display_specifications.hcs_clean_dictionaries import HCSquestions, HCS_orderedCats, HCS_MCsubquestions
from .data.display_specifications.hcs_clean_dictionaries import HCS_colnamesDict, abbrevCenterAffilDict, HCS_MCList
from .data.display_specifications.hcs_clean_dictionaries import HCS_dtypesWOmc, HCS_MCList, HCS_MCsubquestions
from .text_display import *
from .data.display_specifications.hcs_clean_dictionaries import FILTER_OPTIONS, BARCHART_ALLOWED
from .data.display_specifications.hmc_custom_layout import hmc_custom_css_accordion


# GLOBAL
LANGUAGE = os.environ.get('LANGUAGE_DASHBOARD', 'EN') #'DE'
ACCORDION_WIDTH = int(DEFAULT_FIGURE_WIDTH*2) # maybe this can be made dynamic. 
# This is the only width parameter to which everything streches to 

pn.config.loading_spinner = 'dots'
pn.config.loading_color = '#005AA0'
pn.config.raw_css = [hmc_custom_css_accordion]

# Specific data configuration for the HMC survey data
HCS_COLNAMES_REVERT_DICT = {val:key for key, val in HCS_colnamesDict.items()}
HCSquestions_revert = {}
HCSquestions_revert[LANGUAGE] = {val:key for key, val in HCSquestions[LANGUAGE].items()}
HCS_MCsubquestions_flattened = {}
for key, val in HCS_MCsubquestions.items():
    for ke, va in val.items():
        HCS_MCsubquestions_flattened[ke] = va

# if LANGUAGE = 'DE', we translate the data entries because these will often be used as tick labels


# Small Helpers functions 

def map_qkey_to_question(key: str, lang:str =LANGUAGE)-> str:
    """
    Given a key return the full question to be displayed associated with the key for a given language
    """
    mc_key = key

    if key in HCS_MCList:
        # Multiple choice, all have the same question for now
        mc_key = list(HCS_MCsubquestions[key].keys())[0]
        #print(mc_key)
        index = HCS_COLNAMES_REVERT_DICT[mc_key].split('/')[0]
        #print(index)
    else:
        index = HCS_COLNAMES_REVERT_DICT[mc_key]

    return HCSquestions[lang][index]

def map_question_to_qkey(question: str, lang:str =LANGUAGE) -> list:
    """
    Map a given question String to the corresponding columns keys in the dataframe

    usually this is one column, but for multiple choice this can be several columns.
    """
    column_keys = []
    key = HCSquestions_revert[lang][question]
    if key in HCS_MCList:
        print(f'Multiple Choice,{key}')
        #for multiple choice this is a list of subquestions
        key_s = key + '/'
        for key in HCS_colnamesDict.keys():
            if key_s in key:
                if not 'other' in key: # for now, needs to be included in HCS_MCsubquestions and others is strange
                    column_keys.append(HCS_colnamesDict[key])
        column_keys.sort() # Wrong sort... _1 _10 _2 ...
    else:
        column_keys.append(HCS_colnamesDict[key])
    return column_keys

# create tabs
def construct_tabs(tab_list):
    return pn.Tabs(*tab_list)#, dynamic=True)

pwd = os.getcwd() # TODO better use the absolute location of the main.py file...
datafilepath= join(pwd, 'survey_dashboard/data/hmc_survey_2021_data_cleaned.csv')
if not os.path.exists(datafilepath):
    from .data.download_data import download_data
    print('Downloading Data')
    download_data()

# For the dashboard presentation, we load some metadata to certain stuff out of the HMC graph.
# However this gets prepared in before in as a new dataframe

desc = Div(text=open(join(dirname(__file__), "description.html")).read(), sizing_mode="stretch_width")
pwd = os.getcwd()
questions_keys = BARCHART_ALLOWED
questions = [map_qkey_to_question(key) for key in questions_keys]

# Data displayed on startup:

# Overview
# TODO combine plots to something nice, high information density
START_DATA_OV1 = map_qkey_to_question("fairFamiliarity") #and ocid and docStructured
START_DATA_OV2 = map_qkey_to_question("yearsInResearch")
START_DATA_OV3 = map_qkey_to_question("researchArea")
START_DATA_OV4 = map_qkey_to_question("pubAmount")

# Methods:
# Software tools, wordclouds, data generation methods

# Questions explorer
START_DATA_BAR = map_qkey_to_question("careerLevel")
START_DATA_BAR2 = map_qkey_to_question("docStructured")
START_DATA_CORR_1 = map_qkey_to_question("careerLevel")
START_DATA_CORR_2 = map_qkey_to_question("docStructured")

FILTER_BY = "researchArea"
FILTER_BY_2 = "dataGenMethod_"

TOOLTIPS=[
    ("Title", "@title"),
    ("Answer", "@x"),
    ("Number of Answers", "@y")
]


# colors of research areas
#ra_colors = {'All': "#75968f", 'Chemistry': "#a5bab7", 'Earth Science':"#c9d9d3", 
#Engineering Science': "#e2e2e2", 'Life Science': "#dfccce", 'Mathematics': "#ddb7b1", 
#'Other': "#cc7878", 'Physics': "#933b41", 'Psychology': "#550b1d"}
re_fields = ['All', 'Cum. Sum', 'Chemistry', 'Earth Science', 'Engineering Science', 'Life Science', 
      'Mathematics', 'Other', 'Physics', 'Psychology', 'Other']
re_c = Category20[len(re_fields)]
ra_colors = {field: re_c[i] for i, field in enumerate(re_fields)}


# Read data
survey_data = pd.read_csv(datafilepath)

# Rename columns to something more human Readable: #TODO stay with orginal
survey_data.rename(columns=HCS_colnamesDict, inplace=True)

# Different sources, because there wil be different filters applied to these.
source = ColumnDataSource(survey_data)
source_corr = ColumnDataSource(survey_data)


def select_data(question, data_filters, data_filters_method, filter_by=FILTER_BY):
    """Select the data to display"""
    print(question)
    q_index = map_question_to_qkey(question)
    print(q_index)
    q_index_0 = q_index[0]
    question_full = question
    to_exclude = []

    # due to data cleaning some columns are removed...
    # we ignore them if they are not in the index.... to avoid KeyErrors
    q_index_clean = []
    keys = list(survey_data.keys())
    for key in q_index:
        if key in keys:
            q_index_clean.append(key)

    exclude_nan = True
    if len(q_index) >1:
        exclude_nan = False

    method_include = []
    method_exclude = []
    methods_dict = HCS_MCsubquestions[FILTER_BY_2]
    for method in data_filters_method:
        for key, val in methods_dict.items():
            if val == method:
                method_include.append(key)
                # Cut out the rows out the ones who provided False
                method_exclude.append((key, [False]))
    #print(list(set([FILTER_BY]+ q_index_clean + method_include)))
    #print(method_exclude)


    include_clean = list(set([FILTER_BY]+ q_index_clean + method_include))
    # for now this is greedy, if too slow think of another way
    # we want to display anything in terms of researchArea, todo better was to filter, generalize this
    df = filter_dataframe(survey_data, include=include_clean, exclude=method_exclude, exclude_nan=exclude_nan)# [(q_index, to_exclude)]+
    data_all = get_all_values(df, q_index_clean, display_dict=HCS_MCsubquestions_flattened)

    exclude = []
    for field in re_fields:
        if field not in data_filters:
            exclude.append(field)
    for filter_key in exclude:
        df = df[df[filter_by] != filter_key]
    data, y_keys = prepare_data_research_field(df, q_index) # this add also Cum. Sum.
    if 'All' in data_filters:
        data['All'] = data_all['All']
    #print(data)
    # We create two ColumnDataSources, because they have to be n*n and 
    # it is therefore not posible to put all specifics into one 
    ydata_spec = {}
    colors = []
    for key in data_filters:
        colors.append(ra_colors[key])

    # Enforced order of x and y axis
    xtype = None
    if q_index_0 in HCS_dtypesWOmc.keys():
        xtype = HCS_dtypesWOmc[q_index_0]
    
    if len(q_index) >1: # multiple choice case
        x_range = data['x_value']
        width = 0.1
    elif xtype == 'category':
        x_range = HCS_orderedCats[q_index_0]
        width = 0.1
    else:
        x_range = None
        width = 0.6
    y_range = None


    ydata_spec['y_keys'] = data_filters
    ydata_spec['colors'] = colors
    ydata_spec['legend_labels'] = data_filters
    selected = ColumnDataSource(data=data)
    ydata_spec = ColumnDataSource(data=ydata_spec)

    display_options = {'x_range' : x_range, 'y_range': y_range,
                       'title': f'{question_full}', 'width': width}
    #print(display_options)
    return selected, ydata_spec, display_options



def select_data_corr(question, question2, data_filters, data_filters_method):
    """Select the data to display in the correlation vis"""

    q1_key = map_question_to_qkey(question)
    q2_key = map_question_to_qkey(question2)
    q1_index_0 = q1_key[0]
    q2_index_0 = q2_key[0]
    # Enforced order of x and y axis
    # If something is not a category, use default instead 
    xtype = None
    if q1_index_0 in HCS_dtypesWOmc.keys():
        xtype = HCS_dtypesWOmc[q1_index_0]

    if xtype == 'category':
        x_range = HCS_orderedCats[q1_index_0]
    else:
        x_range = None

    ytype = None
    if q2_index_0 in HCS_dtypesWOmc.keys():
        ytype = HCS_dtypesWOmc[q2_index_0]
    if ytype == 'category':
        y_range = HCS_orderedCats[q2_index_0]
    else:
        y_range = None

    q1_key_clean = []
    keys = list(survey_data.keys())
    for key in q1_key:
        if key in keys:
            q1_key_clean.append(key)

    q2_key_clean = []
    for key in q2_key:
        if key in keys:
            q2_key_clean.append(key)

    exclude_nan = True
    if len(q1_key) >1:
        exclude_nan = False

    
    method_include = []
    method_exclude = []
    methods_dict = HCS_MCsubquestions[FILTER_BY_2]
    for method in data_filters_method:
        for key, val in methods_dict.items():
            if val == method:
                method_include.append(key)
                # Filter out the one who provided False
                method_exclude.append((key, [False]))

    exclude_area = []
    for field in re_fields:
        if field not in data_filters:
            pass
            #exclude_area.append(("researchArea", [field]))
    #exclude_areas = ["researchArea", exclude_area]

    include_clean = list(set([FILTER_BY]+ q2_key_clean + q1_key_clean + method_include))

    # If this is slow to calculate each time, it might make sense to calculate all of these 
    # at start up. i.e n^2 tables, with arbitray filters not possible
    df = filter_dataframe(survey_data, include=include_clean, exclude=method_exclude, exclude_nan=exclude_nan)
    
    # if list, merge somehow..., multi column crosstab


    cross_tab = calculate_crosstab(df, q1_index_0, q2_index_0)
    # marker size is radius, we want the Area to be proportional to the value
    # we also scale the markers with the max values are to small, or depending how many Cat, or 
    # figure width...
    marker_scale = 20.0
    cross_tab['markersize'] = percentage_to_area(cross_tab['percentage'], scale_m=marker_scale)
    cross_tab['x_values'] = cross_tab[q1_index_0]
    cross_tab['y_values'] = cross_tab[q2_index_0]
    cross_tab['color'] = ['#A0235A' for i in cross_tab[q2_index_0]]
    
    # for hover tool
    tooltips = [(f"{q1_key[0]}", "@x_values"), 
                    (f"{q2_key[0]}", "@y_values"),
                  ("total", "@total"),
                  ("percentage", "@percentage")]

    title = f''#{q1_key[0]} in dependence to {q2_key[0]}'
    xlabel = f'{question}'
    ylabel = f'{question2}'

    # Bokeh plots need a ColumnDataSource, but this can be initialized from a pandas
    selected = ColumnDataSource(cross_tab)

    display_options = {'x_range' : x_range, 'y_range' : y_range, 'xlabel': xlabel, 'ylabel': ylabel,
                        'title': title, 'tooltips' : tooltips}

    return selected, display_options, marker_scale

def select_data_wordcloud(data_filters, data_filters_method, content=['dataGenMetdataGenMethodSpec_hodSpec_']):
    """
    Filter data for wordcloud from data filters
    """
    word_list = []

    method_include = []
    method_exclude = []
    methods_dict = HCS_MCsubquestions[FILTER_BY_2]
    method_keys = list(methods_dict.keys())
    for method in data_filters_method:
        for key in method_keys:
            if methods_dict[key] == method:
                method_include.append(key)
                # Filter out the one who provided False
                method_exclude.append((key, [False]))

    if len(data_filters_method) == 0:
        method_include = method_keys
        method_exclude = []


    data_include = []
    if 'dataGenMethodSpec_' in content:
        for i, method in enumerate(method_include):
            id_meth = method[-1]
            if id_meth == 'r': # From other
                id_meth = i+1
            data_include.append('dataGenMethodSpec_{}_1'.format(id_meth))
            data_include.append('dataGenMethodSpec_{}_2'.format(id_meth))
            data_include.append('dataGenMethodSpec_{}_3'.format(id_meth))
    else:
        data_include = content
    df = filter_dataframe(survey_data, include=[FILTER_BY]+method_include+data_include, exclude=method_exclude, as_type ='str')
    exclude = []
    for field in re_fields:
        if field not in data_filters:
            exclude.append(field)
    if 'All' in data_filters:
        exclude = []
    for area in exclude:
        df = df[df[FILTER_BY] != area]
    #print(list(df.keys()))
    #print(data_include)
    # prepare word list
    word_list = []
    for method in data_include:
        #print(df[method])
        w_list = [word for word in df[method] if str(word)!='nan']
        word_list = word_list + w_list #ent.replace(' ', '-') # Add '-'


    return word_list


##### Widgets


#### Control widgets

# global filters
# section probably better than tabs..
#tab1 = ("Filter research area", fig)
#tab2 = ("Filter HFG field", fig2)
#filter_tabs = pn.Tabs(*[tab1, tab2])

multi_choice = pn.widgets.MultiChoice(name=md_text_global_filters_widgets[0][LANGUAGE], value=["All"], options=FILTER_OPTIONS['researchArea'])
multi_choice_method = pn.widgets.MultiChoice(name=md_text_global_filters_widgets[1][LANGUAGE], value=[], options=FILTER_OPTIONS['method'])
#multi_choice_hgf_field = pn.widgets.MultiChoice(name="Filter by HGF research field (Each selected will be shown)", value=["All"], options=FILTER_OPTIONS['HGFresearchfield'])
# for careerlevel there can be only one, so we use a Multiselect instead
#select_careerlevel = pn.widgets.Select(name="Filter by career level.", value=[], options=FILTER_OPTIONS['careerLevel'])
#multi_choice_facility = pn.widgets.MultiChoice(name="Filter by career level.", value=[], options=FILTER_OPTIONS['LargeScaleFacility'])

# Bar chart
# D: question select could also be a slider?
# TODO: get filter options for question
question_select = pn.widgets.Select(name=md_text_select_widgets[0][LANGUAGE], value=START_DATA_BAR,
    options=questions)#, description="Select the survey question, which results should be displayed.")

multi_filter = pn.widgets.MultiChoice(name="Filter by data by question specific filter", value=[], 
    options=FILTER_OPTIONS['method'], visible=False)

question_select2 = pn.widgets.Select(name=md_text_select_widgets[1][LANGUAGE], value=START_DATA_BAR2,
    options=questions)#, description="Select the survey question, which results should be displayed.")

multi_filter2 = pn.widgets.MultiChoice(name="Filter by data by question specific filter", value=[], 
    options=FILTER_OPTIONS['method'], visible=False)



# D: better than a Select would be to use the HMC template for this...
# D: Maybe have two dashboards running a German and a English one and link build in the link in the template...
#lang_select = Select(title="Language", value="en",
#               options=['en', 'de'], description="Change the language of the Dashboard.")

chart_select1 =  pn.widgets.Select(title="Visualization type", value="Vertical Bar chart",
               options=['Vertical Bar chart', 'Horizontal Bar chart', 'Pie chart'])
chart_select2 =  pn.widgets.Select(title="Visualization type", value="Vertical Bar chart",
               options=['Vertical Bar chart', 'Horizontal Bar chart', 'Pie chart'])

# Correlation plot
# Not every question can be correlated with every question?
#question_select_corr2 = pn.widgets.Select(name="Question X-Axis", value=START_DATA_CORR_1,
#               options=questions)#, description="Select the survey question which results should be displayed on the X-Axis.")
#question_select_corr3 = pn.widgets.Select(name="Question Y-Axis", value=START_DATA_CORR_2,
#               options=questions)#, description="Select the survey question which results should be displayed on the Y-Axis.")


# Others
plot_aspect_ratio_select = pn.widgets.Select(name="Filter data", value="Cum. Sum",
               options=FILTER_OPTIONS)
menu = ['Barchart', 'Correlation Plot']#('Barchart', 'bar_chart'), ('Correlation Plot', '(corr_plot')]
button_bar = pn.widgets.Select(name="Add a chart", options=menu)


def generate_global_filters():
    g_filters = [multi_choice, multi_choice_method]
    return g_filters


def generate_bar_controls():
    controls_bar = [question_select, multi_filter, chart_select1]
    return controls_bar

#def generate_corr_controls():
#    controls_corr = [question_select_corr2, question_select_corr3]
#    return controls_corr

####################################
# Generate Start figures and panes #
####################################
# TODO, just trigger updates...
data_filters = multi_choice.value
data_filters_method = multi_choice_method.value
print('creating starting figures')

start_display_data, ydata_spec, display_options= select_data(question_select.value, data_filters, data_filters_method)
y_keys = ydata_spec.data['y_keys']
fill_colors = ydata_spec.data['colors']


#fig = pn.pane.Bokeh(bokeh_barchart(start_display_data, y=y_keys, factors=y_keys, legend_labels=y_keys, 
#    fill_color=fill_colors, orientation='vertical', **display_options))

fig_exp1 = pn.pane.Bokeh(bokeh_barchart(start_display_data, y=y_keys, factors=y_keys, legend_labels=y_keys, 
    fill_color=fill_colors, orientation='vertical', **display_options))

start_display_data, ydata_spec, display_options= select_data(question_select2.value, data_filters, data_filters_method)
y_keys = ydata_spec.data['y_keys']
fill_colors = ydata_spec.data['colors']
fig_exp2 = pn.pane.Bokeh(bokeh_barchart(start_display_data, y=y_keys, factors=y_keys, legend_labels=y_keys, 
    fill_color=fill_colors, orientation='vertical', **display_options))

start_corr_data, display_options_corr, marker_scale = select_data_corr(question_select.value, 
    question_select2.value, data_filters, data_filters_method)
fig_corr_1 = bokeh_corr_plot(start_corr_data, **display_options_corr)
fig_corr = pn.pane.Bokeh(fig_corr_1)
leg_corr = pn.pane.Bokeh(create_legend_corr(fig_corr_1, colors=start_corr_data.data['color'], scale_m=marker_scale))

# Overview:

#fig_ov1, fig_ov2, fig_ov3, fig_ov4 = generate_overview()
# for now place holders...
start_display_data, ydata_spec, display_options= select_data(START_DATA_OV1, data_filters, data_filters_method)
y_keys = ydata_spec.data['y_keys']
fig_ov1 = pn.pane.Bokeh(bokeh_barchart(start_display_data, y=y_keys, factors=y_keys, legend_labels=y_keys, 
    fill_color=ydata_spec.data['colors'], orientation='vertical', **display_options))

start_display_data, ydata_spec, display_options= select_data(START_DATA_OV2, data_filters, data_filters_method)
y_keys = ydata_spec.data['y_keys']
fig_ov2 = pn.pane.Bokeh(bokeh_barchart(start_display_data, y=y_keys, factors=y_keys, legend_labels=y_keys, 
    fill_color=ydata_spec.data['colors'], orientation='vertical', **display_options))

start_display_data, ydata_spec, display_options= select_data(START_DATA_OV3, data_filters, data_filters_method)
y_keys = ydata_spec.data['y_keys']
fig_ov3 = pn.pane.Bokeh(bokeh_barchart(start_display_data, y=y_keys, factors=y_keys, legend_labels=y_keys, 
    fill_color=ydata_spec.data['colors'], orientation='vertical', **display_options))

start_display_data, ydata_spec, display_options= select_data(START_DATA_OV4, data_filters, data_filters_method)
y_keys = ydata_spec.data['y_keys']
fig_ov4 = pn.pane.Bokeh(bokeh_barchart(start_display_data, y=y_keys, factors=y_keys, legend_labels=y_keys, 
    fill_color=ydata_spec.data['colors'], orientation='vertical', **display_options))


# Methods, Software and repos

half_width = int(ACCORDION_WIDTH/2)
# Wordcloud of methods #RSDP2b
text_list = select_data_wordcloud(data_filters, data_filters_method, content=["dataGenMethodSpec_"])
wordcloud = generate_wordcloud(text_list, height=DEFAULT_FIGURE_HEIGHT, width=half_width)
svg_pane = pn.pane.Bokeh(interactive_wordcloud(wordcloud), width=wordcloud.width, height=wordcloud.height)
#pn.pane.SVG(wordcloud.to_svg(), width=wordcloud.width, height=wordcloud.height)

# Wordcloud of software #RDMPR10
text_list = select_data_wordcloud(data_filters, data_filters_method, content=["software_1", "software_2", "software_3"])
wordcloud_soft = generate_wordcloud(text_list, height=DEFAULT_FIGURE_HEIGHT, width=half_width)
svg_pane_software = pn.pane.Bokeh(interactive_wordcloud(wordcloud_soft), width=wordcloud.width, height=wordcloud.height)
#pn.pane.SVG(wordcloud_soft.to_svg(), width=wordcloud_soft.width, height=wordcloud_soft.height)

# Wordcloud of repos #DTPUB5
text_list = select_data_wordcloud(data_filters, data_filters_method, content=["pubRepo_1", "pubRepo_2", "pubRepo_3", "pubRepo_4", "pubRepo_5"])
wordcloud_repo = generate_wordcloud(text_list, height=DEFAULT_FIGURE_HEIGHT, width=half_width)
svg_pane_repo = pn.pane.Bokeh(interactive_wordcloud(wordcloud_repo), width=wordcloud.width, height=wordcloud.height)
#pn.pane.SVG(wordcloud_repo.to_svg(), width=wordcloud_repo.width, height=wordcloud_repo.height)


#


def update(target, event, question_sel, f_choice, m_choice, q_filter, charttype):
    """Update the charts
    
    The target will be replaced, the event contains what interaction was trickered.
    Here we assume value change, because no others where allowed.
    """
    print(event)
    question = question_sel#.value
    data_filters = f_choice.value
    data_filters_method = m_choice.value   
    charttype = charttype#.value

    df, ydata_spec, display_options = select_data(question, data_filters, data_filters_method)
    source = df

    y_keys = ydata_spec.data['y_keys']
    fill_colors = ydata_spec.data['colors']
    if charttype == 'Vertical Bar chart':
        fig = bokeh_barchart(source, y=y_keys, factors=y_keys, legend_labels=y_keys, fill_color=fill_colors, orientation='vertical', **display_options)#df.data['factors'], legend_labels='legend_labels')#, figure=figure)
    elif charttype == 'Horizontal Bar chart':
        y_range = display_options['y_range']
        display_options['y_range'] = display_options['x_range']
        display_options['x_range'] = y_range
        # TODO change tooltips...
        fig = bokeh_barchart(source, y=y_keys, factors=y_keys, legend_labels=y_keys, 
        fill_color=fill_colors, orientation='horizontal', xlabel='Number of Answers', ylabel='', **display_options)#'horizontal')#df.data['factors'], legend_labels='legend_labels')#, figure=figure)
    elif charttype == "Pie chart":
        display_options.pop('x_range')
        display_options.pop('y_range')
        display_options.pop('width')
        fig = bokeh_piechart(source, y=y_keys, legend_labels=y_keys, 
        fill_color=fill_colors, **display_options)
    #else:
    #    fig = None
    #    print(f'This chart type does not exists: {charttype}')
    target.object = fig


def update_corr(target, event, question_sel, question_sel2, f_choice, m_choice):
    """Update the correlation plot"""

    print(event)
    print('correlation_plot')
    question = question_sel.value
    question2 = question_sel2.value
    data_filters = f_choice.value
    data_filters_method = m_choice.value
    df, display_options, marker_scale = select_data_corr(question, question2, data_filters, data_filters_method)
    print(df.data)
    print(display_options)
    fig_corr = bokeh_corr_plot(df, **display_options)
    leg_corr = create_legend_corr(fig_corr, colors=df.data['color'], scale_m=marker_scale)

    target.object = fig_corr


def update_wordcloud(target, event, f_choice, m_choice, content):
    """Update the correlation plot"""

    print(event)
    data_filters = f_choice.value
    data_filters_method = m_choice.value

    text_list = select_data_wordcloud(data_filters, data_filters_method, content=content)
    wordcloud = generate_wordcloud(text_list, height=DEFAULT_FIGURE_HEIGHT, width=DEFAULT_FIGURE_WIDTH)
    target.object = interactive_wordcloud(wordcloud)#wordcloud.to_svg()


# TODO It would be better performance wise to filter one time and update all plots
# But I did not figure out how to update a full bunch of things and not only the give instance
# So the update function has to be splitted to archive/cache the filtered data somehow...

def gen_update_overview1(target, event):
    f_choice, m_choice = multi_choice, multi_choice_method
    question_sel = START_DATA_OV1
    update(target, event, question_sel, f_choice, m_choice, q_filter=None, 
        charttype='Vertical Bar chart')

def gen_update_overview2(target, event):
    f_choice, m_choice = multi_choice, multi_choice_method
    question_sel = START_DATA_OV2
    update(target, event, question_sel, f_choice, m_choice, q_filter=None, 
        charttype='Vertical Bar chart')

def gen_update_overview3(target, event):
    f_choice, m_choice = multi_choice, multi_choice_method
    question_sel = START_DATA_OV3
    update(target, event, question_sel, f_choice, m_choice, q_filter=None, 
        charttype='Vertical Bar chart')

def gen_update_overview4(target, event):
    f_choice, m_choice = multi_choice, multi_choice_method
    question_sel = START_DATA_OV4
    update(target, event, question_sel, f_choice, m_choice, q_filter=None, charttype='Vertical Bar chart')

def gen_update_exp1(target, event):
    f_choice, m_choice,  = multi_choice, multi_choice_method
    question_sel, q_filter, charttype = question_select.value, multi_filter, chart_select1.value
    update(target, event, question_sel, f_choice, m_choice, q_filter, charttype)

def gen_update_exp2(target, event):
    f_choice, m_choice,  = multi_choice, multi_choice_method
    question_sel, q_filter, charttype = question_select2.value, multi_filter2, chart_select2.value
    update(target, event, question_sel, f_choice, m_choice, q_filter, charttype)

def gen_update_corr(target, event):
    f_choice, m_choice = multi_choice, multi_choice_method
    question_sel = question_select
    question_sel2 = question_select2
    update_corr(target, event, question_sel, question_sel2, f_choice, m_choice)

def gen_update_wc_methods(target, event):
    f_choice, m_choice = multi_choice, multi_choice_method
    content = ["dataGenMethodSpec_"]
    update_wordcloud(target, event, f_choice, m_choice, content)

def gen_update_wc_software(target, event):
    f_choice, m_choice = multi_choice, multi_choice_method
    content = ["software_1", "software_2", "software_3"]
    update_wordcloud(target, event, f_choice, m_choice, content)

def gen_update_wc_repo(target, event):
    f_choice, m_choice = multi_choice, multi_choice_method
    content = ["pubRepo_1", "pubRepo_2", "pubRepo_3", "pubRepo_4", "pubRepo_5"]
    update_wordcloud(target, event, f_choice, m_choice, content)

# Register Links between widgets and plots and their respective callbacks

g_filters = generate_global_filters()
for control in g_filters:
    control.link(fig_exp1, callbacks={'value': gen_update_exp1})
    control.link(fig_exp2, callbacks={'value': gen_update_exp2})
    control.link(svg_pane, callbacks={'value': gen_update_wc_methods})
    control.link(svg_pane_software, callbacks={'value': gen_update_wc_software})
    control.link(svg_pane_repo, callbacks={'value': gen_update_wc_repo})
    control.link(fig_corr, callbacks={'value': gen_update_corr})
    control.link(fig_ov1, callbacks={'value': gen_update_overview1})
    control.link(fig_ov2, callbacks={'value': gen_update_overview2})
    control.link(fig_ov3, callbacks={'value': gen_update_overview3})
    control.link(fig_ov4, callbacks={'value': gen_update_overview4})

controls_bar = generate_bar_controls()
for control in controls_bar:
    control.link(fig_exp1, callbacks={'value': gen_update_exp1})
    control.link(fig_corr, callbacks={'value': gen_update_corr})

controls_bar2 = [question_select2, multi_filter2, chart_select2]
for control in controls_bar2:
    control.link(fig_exp2, callbacks={'value': gen_update_exp2})
    control.link(fig_corr, callbacks={'value': gen_update_corr})

#controls_corr = generate_corr_controls()
#for control in controls_corr:
#    control.link(fig_corr, callbacks={'value': gen_update_corr})

####################
# Dashboard layout #
####################
print('Creating layout')
# Layout with Panel
# We provide the layout in this explicit way and not all in one list because first 
# we addressed the objects over the rows name, now this may be obsolete



# Global data filters

row1 = pn.Column(md_text_global_filter[LANGUAGE], g_filters[0], g_filters[1], sizing_mode="scale_width")

global_filters_sec = row1

# Overview part
overview_sec = pn.Column(md_text_overview[LANGUAGE], pn.Row(fig_ov3, fig_ov2), pn.Row(fig_ov1, fig_ov4))


# Tools
row4 = pn.Column(md_text_tools_used[LANGUAGE], "## Research and Data Generation Methods :\n", svg_pane, "## Main Software in use:\n", svg_pane_software,"## Repositories Data published in:\n", svg_pane_repo)
methods_tools_sec = row4


# Question Explorer
# Merge Question explorer and Correlation explorer, allow two questions side by side?


# section probably better than tabs..
#tab1 = ("Vertical Bar chart", fig)
#tab2 = ("Horizontal Bar chart", fig2)
#tab3 = ("Pie chart", fig3)
#tabs = construct_tabs([tab1, tab2, tab3])

inputs = pn.Column(*controls_bar, width=half_width)
inputs2 = pn.Column(*controls_bar2, width=half_width)
row2 =  pn.Column(pn.Row(inputs, inputs2), pn.Row(fig_exp1, fig_exp2))
# Correlation 
#inputs_corr = pn.Column(*controls_corr, width=800)
row3 = pn.Column(md_text_corrchart[LANGUAGE], pn.Row(fig_corr, leg_corr))
coree_ex_sec = row3
question_ex_sec = pn.Column(md_text_barchart[LANGUAGE], row2, row3)


#row5 = pn.Row(button_bar)
#layout = pn.Column(row1, md_text_barchart, row2, md_text_corrchart, row3, row4, 
# sizing_mode="scale_both", title='HMC Survey Dashboard')
#md_text_button, row4, sizing_mode="scale_both", title='HMC Survey Dashboard')


# Depending on the layout these could also be in tabs, but then they cannot be viewed together...
overall_accordion = pn.Accordion((accordion_titles[LANGUAGE][0], global_filters_sec),
                                (accordion_titles[LANGUAGE][1], overview_sec),
                                (accordion_titles[LANGUAGE][2], methods_tools_sec),
                                (accordion_titles[LANGUAGE][3], question_ex_sec), sizing_mode="scale_both")#, css_classes=['accordion', 'accordion-header'])#,
                                #('Correlation explorer', coree_ex_sec))
overall_accordion.active = [0,3]#[0,1]
overall_accordion.scroll = True
overall_accordion.margin = 0
overall_accordion.width = ACCORDION_WIDTH
overall_accordion.min_width = ACCORDION_WIDTH

layout = pn.Column(desc, md_text_description[LANGUAGE], overall_accordion)
layout.servable(title='HMC Survey Data Explorer')
print('All done')